@@ -24,7 +24,7 @@ It contains code to convert between different storage formats for localizations
 
 @group XLIFF: *xliff*
 @group Bilingual: pot2po po2tmx oo2po po2oo csv2tbx *wordfast* *ts*
-@group Monolingual: *prop* *dtd* csv2po po2csv *html* *ical* *ini* odf2po po2odf *rc* *txt* moz2po po2moz *php*
+@group Monolingual: *prop* *dtd* csv2po po2csv *html* *ical* *ini* *rc* *txt* moz2po po2moz *php* *sub* *symb* *monopo* *tiki* *web2py* *lang* skype
 @group Support: accesskey convert
 @group Other: poreplace
 """
