@@ -26,7 +26,6 @@ See: http://translate.sourceforge.net/wiki/toolkit/oo2po for examples and
 usage instructions
 """
 
-import os
 import sys
 from translate.storage import po
 from translate.storage import oo
@@ -89,9 +88,8 @@ class oo2po:
         thetargetfile = po.pofile()
         # create a header for the file
         bug_url = 'http://qa.openoffice.org/issues/enter_bug.cgi' + ('''?subcomponent=ui&comment=&short_desc=Localization issue in file: %(filename)s&component=l10n&form_name=enter_issue''' % {"filename": theoofile.filename}).replace(" ", "%20").replace(":", "%3A")
-        targetheader = thetargetfile.makeheader(charset="UTF-8", encoding="8bit", x_accelerator_marker="~", report_msgid_bugs_to=bug_url)
+        targetheader = thetargetfile.init_headers(charset="UTF-8", encoding="8bit", x_accelerator_marker="~", report_msgid_bugs_to=bug_url)
         targetheader.addnote("extracted from %s" % theoofile.filename, "developer")
-        thetargetfile.addunit(targetheader)
         thetargetfile.setsourcelanguage(self.sourcelanguage)
         thetargetfile.settargetlanguage(self.targetlanguage)
         # go through the oo and convert each element
