@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # 
-# Copyright 2002-2008 Zuza Software Foundation
+# Copyright 2002-2009 Zuza Software Foundation
 # 
 # This file is part of translate.
 #
@@ -65,10 +65,14 @@ def applytranslation(entity, dtdunit, inputunit, mixedentities):
                         warnings.warn("Could not find accesskey for %s" % entity)
                     else:
                         original = dtd.unquotefromdtd(dtdunit.definition)
-                        if original.isupper() and unquotedstr.islower():
-                            unquotedstr = unquotedstr.upper()
-                        elif original.islower() and unquotedstr.isupper():
-                            unquotedstr = unquotedstr.lower()
+                        # For the sake of diffs we keep the case of the
+                        # accesskey the same if we know the translation didn't
+                        # change. Casing matters in XUL.
+                        if unquotedstr == dtdunit.source and original.lower() == unquotedstr.lower():
+                            if original.isupper():
+                                unquotedstr = unquotedstr.upper()
+                            elif original.islower():
+                                unquotedstr = unquotedstr.lower()
     if len(unquotedstr) > 0:
         dtdunit.definition = dtd.quotefordtd(dtd.removeinvalidamps(entity, unquotedstr))
 
@@ -121,7 +125,7 @@ class po2dtd:
         if msgidcomment:
             locnote = quote.unstripcomment("LOCALIZATION NOTE ("+dtdunit.entity+"): "+msgidcomment)
             dtdunit.comments.append(("locnote", locnote))
-             
+
 
     def convertstrings(self, inputunit, dtdunit):
         if inputunit.istranslated():
