@@ -28,7 +28,6 @@ usage instructions
 import os.path
 from translate.convert import po2dtd
 from translate.convert import po2prop
-from translate.convert import po2html
 from translate.convert import prop2mozfunny
 from translate.storage import xpi
 from translate.convert import convert
@@ -66,7 +65,7 @@ class MozConvertOptionParser(convert.ArchiveConvertOptionParser):
         # TODO: not sure if this should be here, was in po2moz
         d, n = os.path.dirname(inputpath), os.path.basename(inputpath)
         s = n.find(".")
-        if s == '-1':
+        if s == -1:
             return (inputpath, "")
         root = os.path.join(d, n[:s])
         ext = n[s+1:]
@@ -86,8 +85,6 @@ def main(argv=None):
     # handle command line options
     formats = {("dtd.po", "dtd"): ("dtd", po2dtd.convertdtd),
                ("properties.po", "properties"): ("properties", po2prop.convertmozillaprop),
-               ("xhtml.po", "xhtml"): ("xhtml", po2html.converthtml),
-               ("html.po", "html"): ("html", po2html.converthtml),
                ("it.po", "it"): ("it", prop2mozfunny.po2it),
                ("ini.po", "ini"): ("ini", prop2mozfunny.po2ini),
                ("inc.po", "inc"): ("inc", prop2mozfunny.po2inc),
