@@ -28,6 +28,7 @@ usage instructions
 
 from translate.misc import quote
 from translate.storage import po
+from translate.storage.properties import find_delimiter
 
 eol = "\n"
 
@@ -75,9 +76,9 @@ class reprop:
             returnline = quote.rstripeol(line)+eol
         else:
             line = quote.rstripeol(line)
-            equalspos = line.find('=')
-            # if no equals, just repeat it
-            if equalspos == -1:
+            delimiter_char, delimiter_pos = find_delimiter(line)
+            # if no delimiter, just repeat it
+            if delimiter_pos == -1:
                 returnline = quote.rstripeol(line)+eol
             # otherwise, this is a definition
             else:
@@ -85,21 +86,21 @@ class reprop:
                 if quote.rstripeol(line)[-1:] == '\\':
                     self.inmultilinemsgid = True
                 # now deal with the current string...
-                key = line[:equalspos].strip()
+                key = line[:delimiter_pos].strip()
                 # Calculate space around the equal sign
-                prespace = line.lstrip()[line.lstrip().find(' '):equalspos]
-                postspacestart = len(line[equalspos+1:])
-                postspaceend = len(line[equalspos+1:].lstrip())
-                postspace = line[equalspos+1:equalspos+(postspacestart-postspaceend)+1]
+                prespace = line.lstrip()[line.lstrip().find(' '):delimiter_pos]
+                postspacestart = len(line[delimiter_pos+1:])
+                postspaceend = len(line[delimiter_pos+1:].lstrip())
+                postspace = line[delimiter_pos+1:delimiter_pos+(postspacestart-postspaceend)+1]
                 if self.inputdict.has_key(key):
                     self.inecho = False
                     value = self.inputdict[key]
                     if isinstance(value, str):
                         value = value.decode('utf8')
                     if self.personality == "mozilla" or self.personality == "skype":
-                        returnline = key+prespace+"="+postspace+quote.mozillapropertiesencode(value)+eol
+                        returnline = key+prespace+delimiter_char+postspace+quote.mozillapropertiesencode(value)+eol
                     else:
-                        returnline = key+prespace+"="+postspace+quote.javapropertiesencode(value)+eol
+                        returnline = key+prespace+delimiter_char+postspace+quote.javapropertiesencode(value)+eol
                 else:
                     self.inecho = True
                     returnline = line+eol
