@@ -30,7 +30,7 @@ from translate.storage import rc
 class rerc:
     def __init__(self, templatefile, charset="utf-8", lang=None, sublang=None):
         self.templatefile = templatefile
-        self.templatestore = rc.rcfile(templatefile)
+        self.templatestore = rc.rcfile(templatefile, encoding=charset)
         self.inputdict = {}
         self.charset = charset
         self.lang = lang
@@ -95,7 +95,7 @@ def main(argv=None):
         help="charset to use to decode the RC files (default: %s)" % defaultcharset, metavar="CHARSET")
     parser.add_option("-l", "--lang", dest="lang", default=None,
         help="LANG entry", metavar="LANG")
-    defaultsublang="SUBLANG_DEFAULT"
+    defaultsublang = "SUBLANG_DEFAULT"
     parser.add_option("", "--sublang", dest="sublang", default=defaultsublang,
         help="SUBLANG entry (default: %s)" % defaultsublang, metavar="SUBLANG")
     parser.passthrough.append("charset")
