@@ -56,11 +56,11 @@ def prop2it(pf):
             if comment.startswith("# converted from") and "pseudo-properties" in comment:
                 pass
             elif comment.startswith("# section: "):
-                yield comment.replace("# section: ", "", 1)
+                yield comment.replace("# section: ", "", 1) + "\n"
             else:
-                yield comment.replace("#", ";", 1)
+                yield comment.replace("#", ";", 1) + "\n"
         if unit.isblank():
-            yield "\n"
+            yield ""
         else:
             definition = "%s=%s\n" % (unit.name, unit.value)
             if isinstance(definition, unicode):
@@ -79,7 +79,7 @@ def prop2funny(src, itencoding="cp1252"):
         lines = lines[1:]
     if not (waspseudoprops ^ wasdefines):
         raise ValueError("could not determine file type as pseudo-properties or defines file")
-    pf = properties.propfile()
+    pf = properties.propfile(personality="mozilla")
     pf.parse("\n".join(lines))
     if wasdefines:
         for line in prop2inc(pf):
@@ -93,14 +93,14 @@ def po2inc(inputfile, outputfile, templatefile, encoding=None, includefuzzy=Fals
     outputpropfile = StringIO()
     if templatefile is not None:
         templatelines = templatefile.readlines()
-        templateproplines = [mozfunny2prop.encodepropline(line) for line in mozfunny2prop.inc2prop(templatelines)]
+        templateproplines = [line for line in mozfunny2prop.inc2prop(templatelines)]
         templatepropfile = StringIO("".join(templateproplines))
     else:
         templatepropfile = None
     result = po2prop.convertmozillaprop(inputfile, outputpropfile, templatepropfile, includefuzzy=includefuzzy)
     if result:
         outputpropfile.seek(0)
-        pf = properties.propfile(outputpropfile)
+        pf = properties.propfile(outputpropfile, personality="mozilla")
         outputlines = prop2inc(pf)
         outputfile.writelines(outputlines)
     return result
@@ -110,14 +110,14 @@ def po2it(inputfile, outputfile, templatefile, encoding="cp1252", includefuzzy=F
     outputpropfile = StringIO()
     if templatefile is not None:
         templatelines = templatefile.readlines()
-        templateproplines = [mozfunny2prop.encodepropline(line) for line in mozfunny2prop.it2prop(templatelines, encoding=encoding)]
+        templateproplines = [line for line in mozfunny2prop.it2prop(templatelines, encoding=encoding)]
         templatepropfile = StringIO("".join(templateproplines))
     else:
         templatepropfile = None
     result = po2prop.convertmozillaprop(inputfile, outputpropfile, templatepropfile, includefuzzy=includefuzzy)
     if result:
         outputpropfile.seek(0)
-        pf = properties.propfile(outputpropfile)
+        pf = properties.propfile(outputpropfile, personality="mozilla")
         outputlines = prop2it(pf)
         for line in outputlines:
             line = line.decode("utf-8").encode(encoding)
