@@ -3,7 +3,7 @@
 from translate.convert import po2xliff
 from translate.storage import po
 from translate.storage import poxliff
-from translate.storage import lisa
+from translate.misc.xml_helpers import XML_NS, getText
 
 class TestPO2XLIFF:
 
@@ -30,7 +30,7 @@ class TestPO2XLIFF:
         assert xliff.translate("bla") is None
  
     def test_basic(self):
-        minipo = """# Afrikaans translation of program ABC
+        minipo = r"""# Afrikaans translation of program ABC
 #
 msgid ""
 msgstr ""
@@ -72,7 +72,6 @@ msgstr "Eerste deel "
         print str(xliff)
         assert xliff.translate('First part and extra') == 'Eerste deel en ekstra'
 
-        
     def test_escapednewlines(self):
         """Test the escaping of newlines"""
         minipo = r'''msgid "First line\nSecond line"
@@ -126,7 +125,7 @@ msgstr "Gebruik \\\"."
         """Returns all the information in the context nodes as a list of tuples
         of (type, text)"""
         contexts = node.findall(".//{%s}context" % namespace)
-        return [(context.get("context-type"), lisa.getText(context)) for context in contexts]
+        return [(context.get("context-type"), getText(context)) for context in contexts]
 
     def test_locationcomments(self):
         minipo = r'''#: file.c:123 asdf.c
@@ -199,7 +198,7 @@ msgstr "kunye"
 #, fuzzy
 msgid ""
 msgstr ""
-"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
 '''
         xliff = self.po2xliff(minipo)
         print "The generated xml:"
@@ -207,10 +206,10 @@ msgstr ""
         print xmltext
         assert len(xliff.units) == 1
         unit = xliff.units[0]
-        assert unit.source == unit.target == "MIME-Version: 1.0\n"
+        assert unit.source == unit.target == "Content-Type: text/plain; charset=UTF-8\n"
         assert unit.xmlelement.get("restype") == "x-gettext-domain-header"
         assert unit.xmlelement.get("approved") != "yes"
-        assert unit.xmlelement.get("{%s}space" % lisa.XML_NS) == "preserve"
+        assert unit.xmlelement.get("{%s}space" % XML_NS) == "preserve"
         assert unit.getnotes("po-translator") == "Pulana  Translation for bla\nHallo Ma!"
 
     def test_fuzzy(self):
