@@ -133,8 +133,8 @@ msgstr[1] "%d handleidings."
         potsource = '''#: location.c:1\nmsgid ""\n"_: location.c:1\\n"\n"Source"\nmsgstr ""\n\n''' + \
                     '''#: location.c:10\nmsgid ""\n"_: location.c:10\\n"\n"Source"\nmsgstr ""\n'''
         posource = '''#: location.c:1\n#: location.c:10\nmsgid "Source"\nmsgstr "Target"\n\n'''
-        poexpected1 = '''#: location.c:1\nmsgid ""\n"_: location.c:1\\n"\n"Source"\nmsgstr "Target"\n'''
-        poexpected2 = '''#: location.c:10\nmsgid ""\n"_: location.c:10\\n"\n"Source"\nmsgstr "Target"\n'''
+        poexpected1 = '''#: location.c:1\n#, fuzzy\nmsgid ""\n"_: location.c:1\\n"\n"Source"\nmsgstr "Target"\n'''
+        poexpected2 = '''#: location.c:10\n#, fuzzy\nmsgid ""\n"_: location.c:10\\n"\n"Source"\nmsgstr "Target"\n'''
         newpo = self.convertpot(potsource, posource)
         print "Expected:\n", poexpected1, "Actual:\n", newpo.units[1]
         assert str(newpo.units[1]) == poexpected1
@@ -250,6 +250,7 @@ msgid ""
 msgstr "Sertifikate"
 '''
         expected = r'''#: pref.certs.title
+#, fuzzy
 msgid ""
 "_: pref.certs.title\n"
 "Certificates"
@@ -323,11 +324,11 @@ msgstr "Sertifikate"
 
     def test_merging_resurect_obsolete_messages_into_msgidcomment(self):
         """check that we can reuse old obsolete messages even if the recipient has a msgidcomment"""
-        potsource = '''#: resurect1.c\nmsgid ""\n"_: resurect1.c\\n"\n"About"\nmsgstr ""\n\n''' + \
+        potsource = '''#: resurect1.c\nmsgid "About"\nmsgstr ""\n\n''' + \
                     '''#: resurect2.c\nmsgid ""\n"_: resurect2.c\\n"\n"About"\nmsgstr ""\n'''
         posource = '''#~ msgid "About"\n#~ msgstr "Omtrent"\n'''
-        expected1 = '''#: resurect1.c\nmsgid ""\n"_: resurect1.c\\n"\n"About"\nmsgstr "Omtrent"\n'''
-        expected2 = '''#: resurect2.c\nmsgid ""\n"_: resurect2.c\\n"\n"About"\nmsgstr "Omtrent"\n'''
+        expected1 = '''#: resurect1.c\nmsgid "About"\nmsgstr "Omtrent"\n'''
+        expected2 = '''#: resurect2.c\n#, fuzzy\nmsgid ""\n"_: resurect2.c\\n"\n"About"\nmsgstr "Omtrent"\n'''
         newpo = self.convertpot(potsource, posource)
         print newpo
         assert len(newpo.units) == 3
@@ -394,7 +395,7 @@ msgstr ""
         print newpo
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == poexpected
-        
+
     def test_merging_typecomments(self):
         """Test that we can merge with typecomments"""
         potsource = '''#: file.c:1\n#, c-format\nmsgid "%d pipes"\nmsgstr ""\n''' 
@@ -413,6 +414,95 @@ msgstr ""
         assert newpounit.isfuzzy()
         assert newpounit.hastypecomment("c-format")
 
+    def test_msgctxt(self):
+        """Test that msgctxt is migrated correctly"""
+        potsource = """
+#: something.h:5
+msgctxt "context1"
+msgid "text"
+msgstr ""
+
+#: something.h:6
+msgctxt "context2"
+msgid "text"
+msgstr ""
+"""
+        posource = """
+#: something.h:3
+msgctxt "context0"
+msgid "text"
+msgstr "teks"
+
+#: something.h:4
+msgctxt "context1"
+msgid "text"
+msgstr "sms"
+"""
+        poexpected = """
+#: something.h:5
+msgctxt "context1"
+msgid "text"
+msgstr "sms"
+
+#: something.h:6
+#, fuzzy
+msgctxt "context2"
+msgid "text"
+msgstr "teks"
+"""
+        newpo = self.convertpot(potsource, posource)
+        print newpo
+        assert poexpected in str(newpo)
+
+    def test_empty_msgid(self):
+        """Test that we handle empty msgids correctly."""
+        #TODO: this test will fail if we don't have the gettext location
+        # comment in the pot file
+        potsource = '#: file:1\nmsgctxt "bla"\nmsgid ""\nmsgstr ""\n'
+        posource = r"""
+msgid ""
+"Project-Id-Version: Pootle 0.10\n"
+msgstr ""
+
+msgctxt "bla"
+msgid ""
+msgstr "trans"
+"""
+        newpo = self.convertpot(potsource, posource)
+        print newpo
+        assert len(newpo.units) == 2
+        assert newpo.units[0].isheader()
+        unit = newpo.units[1]
+        assert unit.source == u""
+        assert unit.getid() == u"bla\04"
+        assert unit.target == "trans"
+        assert not unit.isfuzzy()
+
+    def test_migrate_msgidcomment_to_msgctxt(self):
+        """Test that we migrate correctly from msgidcomments to msgctxt.
+
+        This is needed for our move away from using msgidcomments for mozilla."""
+        potsource = '#: bla\nmsgctxt "bla"\nmsgid ""\nmsgstr ""'
+        posource = r"""
+msgid ""
+"Project-Id-Version: Pootle 0.10\n"
+msgstr ""
+
+#: bla
+msgid ""
+"_: bla\n"
+msgstr "trans"
+"""
+        newpo = self.convertpot(potsource, posource)
+        print newpo
+        assert len(newpo.units) == 2
+        assert newpo.units[0].isheader()
+        unit = newpo.units[1]
+        assert unit.source == u""
+        assert unit.getid() == u"bla\04"
+        assert unit.target == "trans"
+        assert not unit.isfuzzy()
+
     def test_obsolete_msgctxt(self):
         """Test that obsolete units' msgctxt is preserved."""
         potsource = 'msgctxt "newContext"\nmsgid "First unit"\nmsgstr ""'
@@ -440,6 +530,69 @@ msgstr "Eerste eenheid"
         assert 'msgctxt "context"' in str(newpo.units[2])
         assert 'msgctxt "context2"' in str(newpo.units[3])
 
+    def test_small_strings(self):
+        """Test that units with small source strings are not incorrectly
+        populated by means of fuzzy matching."""
+        potsource = r'''#, fuzzy
+msgid ""
+msgstr ""
+"Project-Id-Version: PACKAGE VERSION\n"
+"Report-Msgid-Bugs-To: new@example.com\n"
+"POT-Creation-Date: 2006-11-11 11:11+0000\n"
+"PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
+"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
+"Language-Team: LANGUAGE <LL@li.org>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\n"
+"X-Generator: Translate Toolkit 0.10rc2\n"
+
+#: new_disassociated_mozilla_accesskey
+msgid "R"
+msgstr ""
+'''
+        posource = r'''msgid ""
+msgstr ""
+"Project-Id-Version: Pootle 0.10\n"
+"Report-Msgid-Bugs-To: old@example.com\n"
+"POT-Creation-Date: 2006-01-01 01:01+0100\n"
+"PO-Revision-Date: 2006-09-09 09:09+0900\n"
+"Last-Translator: Joe Translate <joe@example.com>\n"
+"Language-Team: Pig Latin <piglatin@example.com>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Translate Toolkit 0.9\n"
+
+#: old_disassociated_mozilla_accesskey
+msgid "R"
+msgstr "S"
+'''
+        expected = r'''msgid ""
+msgstr ""
+"Project-Id-Version: Pootle 0.10\n"
+"Report-Msgid-Bugs-To: new@example.com\n"
+"POT-Creation-Date: 2006-11-11 11:11+0000\n"
+"PO-Revision-Date: 2006-09-09 09:09+0900\n"
+"Last-Translator: Joe Translate <joe@example.com>\n"
+"Language-Team: Pig Latin <piglatin@example.com>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Generator: Translate Toolkit 0.10rc2\n"
+
+#: new_disassociated_mozilla_accesskey
+msgid "R"
+msgstr ""
+'''
+        newpo = self.convertpot(potsource, posource)
+        print 'Output:\n%s' % newpo
+        print 'Expected:\n%s' % expected
+        assert str(newpo) == expected
+
 
 class TestPOT2POCommand(test_convert.TestConvertCommand, TestPOT2PO):
     """Tests running actual pot2po commands on files"""
