@@ -71,10 +71,10 @@ class TestProp2PO:
         pounit = self.singleelement(pofile)
         assert pounit.source == "This setence has a space then tab at the end. \t"
         
-        propsource = r"SPACE_AT_END=This setence will lose its 4 spaces at the end.    "
+        propsource = r"SPACE_AT_END=This setence will keep its 4 spaces at the end.    "
         pofile = self.prop2po(propsource)
         pounit = self.singleelement(pofile)
-        assert pounit.source == "This setence will lose its 4 spaces at the end."
+        assert pounit.source == "This setence will keep its 4 spaces at the end.    "
         
         propsource = r"SPACE_AT_END_NO_TRIM=This setence will keep its 4 spaces at the end.\\    "
         pofile = self.prop2po(propsource)
@@ -116,6 +116,22 @@ prefPanel-smime=Security'''
         pounit = self.singleelement(pofile)
         assert pounit.getnotes("developer") == "# Comment"
 
+    def test_multiline_comments(self):
+        """test to ensure that we handle multiline comments well"""
+        propsource = '''# Comment
+# commenty 2
+
+## @name GENERIC_ERROR
+## @loc none
+prefPanel-smime=
+'''
+        pofile = self.prop2po(propsource)
+        print str(pofile)
+        #header comments:
+        assert "#. # Comment\n#. # commenty 2" in str(pofile)
+        pounit = self.singleelement(pofile)
+        assert pounit.getnotes("developer") == "## @name GENERIC_ERROR\n## @loc none"
+
     def wtest_folding_accesskeys(self):
         """check that we can fold various accesskeys into their associated label (bug #115)"""
         propsource = r'''cmd_addEngine = Add Engines...
@@ -140,6 +156,7 @@ do=translate me
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["credit"]
         assert pounit.getcontext() == "credit"
+        assert 'msgctxt "credit"' in str(pounit)
         assert "#. # comment" in str(pofile)
         assert pounit.source == ""
 
@@ -188,5 +205,6 @@ class TestProp2POCommand(test_convert.TestConvertCommand, TestProp2PO):
         options = test_convert.TestConvertCommand.test_help(self)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
+        options = self.help_check(options, "--personality=TYPE")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
 
