@@ -146,7 +146,8 @@ def getmtime(filename):
 class oocheckfilter(pofilter.pocheckfilter):
     def validelement(self, unit, filename, filteraction):
         """Returns whether or not to use unit in conversion. (filename is just for error reporting)"""
-        if filteraction == "none": return True
+        if filteraction == "none":
+            return True
         filterresult = self.filterunit(unit)
         if filterresult:
             if filterresult != autocorrect:
@@ -172,7 +173,6 @@ class oofilteroptions:
     excludefilters = {}
     includefuzzy = False
     includereview = False
-    includeheader = False
     autocorrect = False
 
 options = oofilteroptions()
