@@ -27,37 +27,47 @@ from translate.lang import data
 
 def spacestart(str1):
     """returns all the whitespace from the start of the string"""
-    newstring = ""
+    newstring = u""
     for c in str1:
-        if not c.isspace(): return newstring
-        else: newstring += c
+        if c.isspace():
+            newstring += c
+        else:
+            break
     return newstring
 
 def spaceend(str1):
     """returns all the whitespace from the end of the string"""
-    newstring = ""
+    newstring = u""
     for n in range(len(str1)):
         c = str1[-1-n]
-        if not c.isspace(): return newstring
-        else: newstring = c + newstring
+        if c.isspace():
+            newstring = c + newstring
+        else:
+            break
     return newstring
 
 def puncstart(str1, punctuation):
     """returns all the punctuation from the start of the string"""
-    newstring = ""
+    newstring = u""
     for c in str1:
-        if c not in punctuation and not c.isspace(): return newstring
-        else: newstring += c
+        if c in punctuation or c.isspace():
+            newstring += c
+        else:
+            break
     return newstring
 
 def puncend(str1, punctuation):
     """returns all the punctuation from the end of the string"""
-    newstring = ""
+    # An implementation with regular expressions was slightly slower.
+
+    newstring = u""
     for n in range(len(str1)):
         c = str1[-1-n]
-        if c not in punctuation and not c.isspace(): return newstring
-        else: newstring = c + newstring
-    return newstring
+        if c in punctuation or c.isspace():
+            newstring = c + newstring
+        else:
+            break
+    return newstring.replace(u"\u00a0", u" ")
 
 def ispurepunctuation(str1):
     """checks whether the string is entirely punctuation"""
@@ -112,7 +122,8 @@ def findaccelerators(str1, accelmarker, acceptlist=None):
             currentpos += len(accelmarker)
             # we assume accelerators are single characters
             accelend = currentpos + 1
-            if accelend > len(str1): break
+            if accelend > len(str1):
+                break
             accelerator = str1[currentpos:accelend]
             currentpos = accelend
             if isvalidaccelerator(accelerator, acceptlist):
@@ -138,19 +149,22 @@ def findmarkedvariables(str1, startmarker, endmarker, ignorelist=[]):
                     if not (str1[n].isalnum() or str1[n] == '_'):
                         endmatch = n
                         break
-                if currentpos == endmatch: endmatch = len(str1)
+                if currentpos == endmatch:
+                    endmatch = len(str1)
                 if currentpos < endmatch:
                     variable = str1[currentpos:endmatch]
                 currentpos = endmatch
             elif type(endmarker) == int:
                 # setting endmarker to an int means it is a fixed-length variable string (usually endmarker==1)
                 endmatch = currentpos + endmarker
-                if endmatch > len(str1): break
+                if endmatch > len(str1):
+                    break
                 variable = str1[currentpos:endmatch]
                 currentpos = endmatch
             else:
                 endmatch = str1.find(endmarker, currentpos)
-                if endmatch == -1: break
+                if endmatch == -1:
+                    break
                 # search backwards in case there's an intervening startmarker (if not it's OK)...
                 start2 = str1.rfind(startmarker, currentpos, endmatch)
                 if start2 != -1:
