@@ -29,14 +29,16 @@ for full descriptions of all tests
 """
 
 from translate.storage import factory
+from translate.storage.poheader import poheader
 from translate.filters import checks
 from translate.filters import autocorrect
 from translate.misc import optrecurse
+
 import os
 
 class pocheckfilter:
     def __init__(self, options, checkerclasses=None, checkerconfig=None):
-        # excludefilters={}, limitfilters=None, includeheader=False, includefuzzy=True, includereview=True, autocorrect=False):
+        # excludefilters={}, limitfilters=None, includefuzzy=True, includereview=True, autocorrect=False):
         """builds a checkfilter using the given checker (a list is allowed too)"""
         if checkerclasses is None:
             checkerclasses = [checks.StandardChecker, checks.StandardUnitChecker]
@@ -57,9 +59,12 @@ class pocheckfilter:
 
     def filterunit(self, unit):
         """runs filters on an element"""
-        if unit.isheader(): return []
-        if not self.options.includefuzzy and unit.isfuzzy(): return []
-        if not self.options.includereview and unit.isreview(): return []
+        if unit.isheader():
+            return []
+        if not self.options.includefuzzy and unit.isfuzzy():
+            return []
+        if not self.options.includereview and unit.isreview():
+            return []
         failures = self.checker.run_filters(unit)
         if failures and self.options.autocorrect:
             # we can't get away with bad unquoting / requoting if we're going to change the result...
@@ -79,8 +84,8 @@ class pocheckfilter:
         Return value:
             - A new translation store object with the results of the filter included."""
         newtransfile = type(transfile)()
-        if self.options.includeheader and newtransfile.units > 0:
-            newtransfile.addunit(transfile.header())
+        newtransfile.setsourcelanguage(transfile.sourcelanguage)
+        newtransfile.settargetlanguage(transfile.targetlanguage)
         for unit in transfile.units:
             filterresult = self.filterunit(unit)
             if filterresult:
@@ -91,6 +96,8 @@ class pocheckfilter:
                         if isinstance(filtermessage, checks.SeriousFilterFailure):
                             unit.markfuzzy()
                 newtransfile.addunit(unit)
+        if isinstance(newtransfile, poheader):
+            newtransfile.updateheader(add=True, **transfile.parseheader())
         return newtransfile
 
 class FilterOptionParser(optrecurse.RecursiveOptionParser):
@@ -175,9 +182,6 @@ def cmdlineparser():
     parser.add_option("", "--nofuzzy", dest="includefuzzy",
         action="store_false", default=True,
         help="exclude units marked fuzzy")
-    parser.add_option("", "--header", dest="includeheader",
-        action="store_true", default=False,
-        help="include a PO header in the output")
     parser.add_option("", "--nonotes", dest="addnotes",
         action="store_false", default=True,
         help="don't add notes about the errors")
