@@ -48,8 +48,10 @@ def removekdecomments(str1):
 
 def filteraccelerators(accelmarker):
     """returns a function that filters accelerators marked using accelmarker in strings"""
-    if accelmarker is None: accelmarkerlen = 0
-    else: accelmarkerlen = len(accelmarker)
+    if accelmarker is None:
+        accelmarkerlen = 0
+    else:
+        accelmarkerlen = len(accelmarker)
     def filtermarkedaccelerators(str1, acceptlist=None):
         """modifies the accelerators in str1 marked with a given marker, using a given filter"""
         acclocs, badlocs = decoration.findaccelerators(str1, accelmarker, acceptlist)
