@@ -25,17 +25,19 @@ import sys
 
 available = False
 
-# Let us see what is available in our preferred order
 try:
     # Enchant
-    from enchant import checker, DictNotFoundError
+    from enchant import checker, DictNotFoundError, Error as EnchantError
     available = True
     checkers = {}
     def check(text, lang):
         if not lang in checkers:
             try:
                 checkers[lang] = checker.SpellChecker(lang)
-            except DictNotFoundError, e:
+                # some versions only report an error when checking something
+                checkers[lang].check('')
+            except EnchantError, e:
+                # sometimes this is raised instead of DictNotFoundError
                 print >> sys.stderr, str(e)
                 checkers[lang] = None
 
@@ -47,14 +49,6 @@ try:
             yield err.word, err.wordpos, err.suggest()
 
 except ImportError:
-    try:
-        # jToolkit might be installed and might give access to aspell, for 
-        # example
-        from jToolkit import spellcheck
-        available = True
-        check = spellcheck.check
-    except ImportError:
-
-        def check(text, lang):
-            return []
+    def check(text, lang):
+        return []
 
