@@ -190,6 +190,11 @@ def test_doublequoting():
     vichecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage="vi"))
     assert passes(vichecker.doublequoting, 'Save "File"', u"Lưu « Tập tin »")
 
+    # Had a small exception with such a case:
+    eschecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage="es"))
+    assert passes(eschecker.doublequoting, "<![CDATA[ Enter the name of the Windows workgroup that this server should appear in. ]]>",
+            "<![CDATA[ Ingrese el nombre del grupo de trabajo de Windows en el que debe aparecer este servidor. ]]>")
+
 def test_doublespacing():
     """tests double spacing"""
     stdchecker = checks.StandardChecker()
@@ -241,6 +246,7 @@ def test_endpunc():
 
     stdchecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage='fr'))
     assert passes(stdchecker.endpunc, "Header:", u"En-tête :")
+    assert passes(stdchecker.endpunc, "Header:", u"En-tête\u00a0:")
 
 def test_endwhitespace():
     """tests endwhitespace"""
@@ -456,6 +462,7 @@ def test_puncspacing():
     # Some languages have padded puntuation marks
     frchecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage="fr"))
     assert passes(frchecker.puncspacing, "Do \"this\"", "Do « this »")
+    assert passes(frchecker.puncspacing, u"Do \"this\"", u"Do «\u00a0this\u00a0»")
     assert fails(frchecker.puncspacing, "Do \"this\"", "Do «this»")
 
 def test_purepunc():
@@ -512,8 +519,8 @@ def test_singlequoting():
     assert passes(ooochecker.singlequoting, "~Don't import anything", "~Moenie enigiets invoer nie")
 
     vichecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage="vi"))
-    assert passes(vichecker.doublequoting, "Save 'File'", u"Lưu « Tập tin »")
-    assert passes(vichecker.doublequoting, "Save `File'", u"Lưu « Tập tin »")
+    assert passes(vichecker.singlequoting, "Save 'File'", u"Lưu « Tập tin »")
+    assert passes(vichecker.singlequoting, "Save `File'", u"Lưu « Tập tin »")
 
 def test_simplecaps():
     """tests simple caps"""
@@ -609,10 +616,16 @@ def test_startpunc():
     assert fails(stdchecker.startpunc, " << Previous", "Wrong")
     assert fails(stdchecker.startpunc, "Question", u"\u2026Wrong")
 
+    assert passes(stdchecker.startpunc, "<fish>hello</fish> world", "world <fish>hello</fish>")
+
     # The inverted Spanish question mark should be accepted
     stdchecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage='es'))
     assert passes(stdchecker.startpunc, "Do you want to reload the file?", u"¿Quiere recargar el archivo?")
 
+    # The Afrikaans indefinite article should be accepted
+    stdchecker = checks.StandardChecker(checks.CheckerConfig(targetlanguage='af'))
+    assert passes(stdchecker.startpunc, "A human?", u"'n Mens?")
+
 def test_startwhitespace():
     """tests startwhitespace"""
     stdchecker = checks.StandardChecker()
@@ -912,6 +925,11 @@ def test_credits():
 def test_gconf():
     """test GNOME gconf errors"""
     gnomechecker = checks.GnomeChecker()
+    # Let's cheat a bit and prepare the checker as the run_filters() method
+    # would do by adding locations needed by the gconf test
+    gnomechecker.locations = []
+    assert passes(gnomechecker.gconf, 'Blah "gconf_setting"', 'Bleh "gconf_setting"')
+    assert passes(gnomechecker.gconf, 'Blah "gconf_setting"', 'Bleh "gconf_steling"')
+    gnomechecker.locations = ['file.schemas.in.h:24']
     assert passes(gnomechecker.gconf, 'Blah "gconf_setting"', 'Bleh "gconf_setting"')
     assert fails(gnomechecker.gconf, 'Blah "gconf_setting"', 'Bleh "gconf_steling"')
-
