@@ -3,10 +3,12 @@
 
 from translate.storage import factory
 from translate.storage import xliff
+from translate.storage.test_base import headerless_len, first_translatable
 from translate.filters import pofilter
 from translate.filters import checks
 from translate.misc import wStringIO
 
+
 class BaseTestFilter(object):
     """Base class for filter tests."""
 
@@ -34,32 +36,34 @@ class BaseTestFilter(object):
     def test_simplepass(self):
         """checks that an obviously correct string passes"""
         filter_result = self.filter(self.translationstore)
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_simplefail(self):
         """checks that an obviously wrong string fails"""
         self.unit.target = "REST"
         filter_result = self.filter(self.translationstore)
-        assert filter_result.units[0].geterrors().has_key('startcaps')
+        print filter_result
+        print filter_result.units
+        assert first_translatable(filter_result).geterrors().has_key('startcaps')
 
     def test_variables_across_lines(self):
         """Test that variables can span lines and still fail/pass"""
         self.unit.source = '"At &timeBombURL."\n"label;."'
         self.unit.target = '"Tydens &tydBombURL."\n"etiket;."'
         filter_result = self.filter(self.translationstore)
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_ignore_if_already_marked(self):
         """check that we don't add another failing marker if the message is already marked as failed"""
         self.unit.target = ''
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--test=untranslated"])
-        errors = filter_result.units[0].geterrors()
+        errors = first_translatable(filter_result).geterrors()
         assert len(errors) == 1
         assert errors.has_key('untranslated')
 
         # Run a filter test on the result, to check that it doesn't mark the same error twice.
         filter_result2 = self.filter(filter_result, cmdlineoptions=["--test=untranslated"])
-        errors = filter_result2.units[0].geterrors()
+        errors = first_translatable(filter_result2).geterrors()
         assert len(errors) == 1
         assert errors.has_key('untranslated')
 
@@ -67,78 +71,78 @@ class BaseTestFilter(object):
         """check that we report an error if a user tries to run a non-existant test"""
         filter_result = self.filter(self.translationstore, cmdlineoptions=["-t nonexistant"])
         # TODO Not sure how to check for the stderror result of: warning: could not find filter  nonexistant
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_list_all_tests(self):
         """lists all available tests"""
         filter_result = self.filter(self.translationstore, cmdlineoptions=["-l"])
         # TODO again not sure how to check the stderror output
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_test_against_fuzzy(self):
         """test whether to run tests against fuzzy translations"""
         self.unit.markfuzzy()
 
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--fuzzy"])
-        assert filter_result.units[0].geterrors().has_key('isfuzzy')
+        assert first_translatable(filter_result).geterrors().has_key('isfuzzy')
 
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--nofuzzy"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
         # Re-initialize the translation store object in order to get an unfuzzy unit
 	# with no filter notes.
         self.setup_method(self)
 
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--fuzzy"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--nofuzzy"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_test_against_review(self):
         """test whether to run tests against translations marked for review"""
         self.unit.markreviewneeded()
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--review"])
-        assert filter_result.units[0].isreview()
+        assert first_translatable(filter_result).isreview()
 
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--noreview"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
         # Re-initialize the translation store object.
         self.setup_method(self)
 
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--review"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--noreview"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_isfuzzy(self):
         """tests the extraction of items marked fuzzy"""
         self.unit.markfuzzy()
 
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--test=isfuzzy"])
-        assert filter_result.units[0].geterrors().has_key('isfuzzy')
+        assert first_translatable(filter_result).geterrors().has_key('isfuzzy')
 
         self.unit.markfuzzy(False)
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--test=isfuzzy"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_isreview(self):
         """tests the extraction of items marked review"""
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--test=isreview"])
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
         self.unit.markreviewneeded()
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--test=isreview"])
-        assert filter_result.units[0].isreview()
+        assert first_translatable(filter_result).isreview()
 
     def test_notes(self):
         """tests the optional adding of notes"""
         # let's make sure we trigger the 'long' and/or 'doubleword' test
         self.unit.target = u"asdf asdf asdf asdf asdf asdf asdf"
         filter_result = self.filter(self.translationstore)
-        assert len(filter_result.units) == 1
-        assert filter_result.units[0].geterrors()
+        assert headerless_len(filter_result.units) == 1
+        assert first_translatable(filter_result).geterrors()
 
         # now we remove the existing error. self.unit is changed since we copy
         # units - very naughty
@@ -147,15 +151,15 @@ class BaseTestFilter(object):
         else:
             self.unit.removenotes()
         filter_result = self.filter(self.translationstore, cmdlineoptions=["--nonotes"])
-        assert len(filter_result.units) == 1
-        assert len(filter_result.units[0].geterrors()) == 0
+        assert headerless_len(filter_result.units) == 1
+        assert len(first_translatable(filter_result).geterrors()) == 0
 
     def test_unicode(self):
         """tests that we can handle UTF-8 encoded characters when there is no known header specified encoding"""
         self.unit.source = u'Bézier curve'
         self.unit.target = u'Bézier-kurwe'
         filter_result = self.filter(self.translationstore)
-        assert len(filter_result.units) == 0
+        assert headerless_len(filter_result.units) == 0
 
     def test_preconditions(self):
         """tests that the preconditions work correctly"""
@@ -163,8 +167,8 @@ class BaseTestFilter(object):
         self.unit.target = ""
         filter_result= self.filter(self.translationstore)
         # We should only get one error (untranslated), and nothing else
-        assert len(filter_result.units) == 1
-        unit = filter_result.units[0]
+        assert headerless_len(filter_result.units) == 1
+        unit = first_translatable(filter_result)
         assert len(unit.geterrors()) == 1
 
 class TestPOFilter(BaseTestFilter):
@@ -174,16 +178,16 @@ class TestPOFilter(BaseTestFilter):
 
     def setup_method(self, method):
         self.translationstore = self.parse_text(self.filetext)
-        self.unit = self.translationstore.units[0]
+        self.unit = first_translatable(self.translationstore)
 
     def test_msgid_comments(self):
         """Tests that msgid comments don't feature anywhere."""
         posource = 'msgid "_: Capital.  ACRONYMN. (msgid) comment 3. %d Extra sentence.\\n"\n"cow"\nmsgstr "koei"\n'
         pofile = self.parse_text(posource)
         filter_result = self.filter(pofile)
-        if len(filter_result.units):
-            print filter_result.units[0]
-        assert len(filter_result.units) == 0
+        if headerless_len(filter_result.units):
+            print first_translatable(filter_result)
+        assert headerless_len(filter_result.units) == 0
 
 class TestXliffFilter(BaseTestFilter):
     """Test class for xliff-specific tests."""
@@ -200,7 +204,7 @@ class TestXliffFilter(BaseTestFilter):
 </xliff>'''
     filename = "test.xlf"
 
-    def set_store_review(review=True):
+    def set_store_review(self, review=True):
         self.filetext = '''<?xml version="1.0" encoding="utf-8"?>
 <xliff version="1.1" xmlns="urn:oasis:names:tc:xliff:document:1.1">
 <file datatype="po" original="example.po" source-language="en-US">
@@ -214,11 +218,11 @@ class TestXliffFilter(BaseTestFilter):
 </xliff>'''
 
         self.translationstore = self.parse_text(self.filetext)
-        self.unit = self.translationstore.units[0]
+        self.unit = first_translatable(self.translationstore)
 
     def setup_method(self, method):
         self.translationstore = self.parse_text(self.filetext)
-        self.unit = self.translationstore.units[0]
+        self.unit = first_translatable(self.translationstore)
 
 class TestTMXFilter(BaseTestFilter):
     """Test class for TMX-specific tests."""
@@ -241,7 +245,7 @@ class TestTMXFilter(BaseTestFilter):
 
     def setup_method(self, method):
         self.translationstore = self.parse_text(self.filetext)
-        self.unit = self.translationstore.units[0]
+        self.unit = first_translatable(self.translationstore)
 
     def test_test_against_fuzzy(self):
         """TMX doesn't support fuzzy"""
