@@ -26,14 +26,16 @@ For more information, see U{http://en.wikipedia.org/wiki/French_language}
 from translate.lang import common
 import re
 
+
 def guillemets(text):
+
     def convertquotation(match):
         prefix = match.group(1)
         # Let's see that we didn't perhaps match an XML tag property like
         # <a href="something">
         if prefix == u"=":
             return match.group(0)
-        return u"%s« %s »" % (prefix, match.group(2))
+        return u"%s«\u00a0%s\u00a0»" % (prefix, match.group(2)) #\u00a0 is NBSP
 
     # Check that there is an even number of double quotes, otherwise it is
     # probably not safe to convert them.
@@ -41,25 +43,28 @@ def guillemets(text):
         text = re.sub('(.|^)"([^"]+)"', convertquotation, text)
     singlecount = text.count(u"'")
     if singlecount:
-        if singlecount % 2 == 0:
-            text = re.sub("(.|^)'([^']+)'", convertquotation, text)
         if singlecount == text.count(u'`'):
             text = re.sub("(.|^)`([^']+)'", convertquotation, text)
+        elif singlecount % 2 == 0:
+            text = re.sub("(.|^)'([^']+)'", convertquotation, text)
     text = re.sub(u'(.|^)“([^”]+)”', convertquotation, text)
     return text
 
+
 class fr(common.Common):
     """This class represents French."""
 
-    validaccel = u"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" + u"éÉ"
+    validaccel = u"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
+                 u"1234567890" + \
+                 u"éÉ"
 
-    # According to http://french.about.com/library/writing/bl-punctuation.htm, 
-    # in French, a space is required both before and after all two- (or more) 
+    # According to http://french.about.com/library/writing/bl-punctuation.htm,
+    # in French, a space is required both before and after all two- (or more)
     # part punctuation marks and symbols, including : ; « » ! ? % $ # etc.
     puncdict = {}
     for c in u":;!?#":
-        puncdict[c] = u" %s" % c
-    # TODO: consider adding % and $, but think about the consequences of how 
+        puncdict[c] = u"\u00a0%s" % c
+    # TODO: consider adding % and $, but think about the consequences of how
     # they could be part of variables
 
     def punctranslate(cls, text):
@@ -72,6 +77,6 @@ class fr(common.Common):
         text = super(cls, cls).punctranslate(text)
         # We might get problems where we got a space in URIs such as
         # http ://
-        text = text.replace(u" ://", "://")
+        text = text.replace(u"\u00a0://", "://")
         return guillemets(text)
     punctranslate = classmethod(punctranslate)
