@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# 
+#
 # Copyright 2007 Zuza Software Foundation
-# 
+#
 # This file is part of translate.
 #
 # translate is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # translate is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -28,12 +28,14 @@ import re
 
 from translate.lang import common
 
+
 class hy(common.Common):
     """This class represents Armenian."""
 
     armenianpunc = u"։՝՜՞"
 
-    punctuation = u"".join([common.Common.commonpunc, common.Common.quotes, common.Common.miscpunc, armenianpunc])
+    punctuation = u"".join([common.Common.commonpunc, common.Common.quotes,
+                            common.Common.miscpunc, armenianpunc])
 
     sentenceend = u"։՝՜…"
 
