@@ -7,7 +7,7 @@ def test_getlanguage():
     """Tests that a basic call to getlanguage() works."""
     kmlanguage = factory.getlanguage('km')
     assert kmlanguage.code == 'km'
-    assert kmlanguage.fullname == 'Khmer'
+    assert kmlanguage.fullname == 'Central Khmer'
     
     # Test a non-exisint code
     language = factory.getlanguage('zz')
@@ -27,7 +27,11 @@ def test_getlanguage():
     # Test with None as language code
     language = factory.getlanguage(None)
     assert language.code == ''
-    
+
     #Test with a language code that is a reserved word in Python
     language = factory.getlanguage('is')
     assert language.nplurals == 2
+
+    #Test with a language code contains '@'
+    language = factory.getlanguage('ca@valencia')
+    assert language.nplurals == 2
