@@ -7,6 +7,7 @@ def test_punctranslate():
     """Tests that we can translate punctuation."""
     language = factory.getlanguage('ko')
     # Nothing should be translated
+    assert language.punctranslate(u"") == u""
     assert language.punctranslate(u"abc efg") == u"abc efg"
     assert language.punctranslate(u"abc efg.") == u"abc efg."
     assert language.punctranslate(u"abc efg. hij.") == u"abc efg. hij."
@@ -17,6 +18,9 @@ def test_punctranslate():
 def test_sentences():
     """Tests basic functionality of sentence segmentation."""
     language = factory.getlanguage('ko')
+    sentences = language.sentences(u"")
+    assert sentences == []
+
     sentences = language.sentences(u"이 연락처에 바뀐 부분이 있습니다. 바뀐 사항을 저장하시겠습니까?")
     print sentences
     assert sentences == [u"이 연락처에 바뀐 부분이 있습니다.", u"바뀐 사항을 저장하시겠습니까?"]
