@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
-# 
+#
 # This file is part of translate.
 #
 # translate is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # translate is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -26,13 +26,13 @@ interface for the PyLucene (v2.x) indexing engine
 take a look at PyLuceneIndexer1.py for the PyLucene v1.x interface
 """
 
-__revision__ = "$Id: PyLuceneIndexer.py 13070 2009-11-13 16:47:01Z alaaosh $"
+__revision__ = "$Id: PyLuceneIndexer.py 14174 2010-04-08 23:14:10Z alaaosh $"
 
 import CommonIndexer
-import tempfile
 import re
 import os
 import time
+import logging
 
 # try to import the PyLucene package (with the two possible names)
 # remember the type of the detected package (compiled with jcc (>=v2.3) or
@@ -81,6 +81,8 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         @param create_allowed: create the database, if necessary; default: True
         @type create_allowed: bool
         """
+        jvm = PyLucene.getVMEnv()
+        jvm.attachCurrentThread()
         super(PyLuceneDatabase, self).__init__(basedir, analyzer=analyzer,
                 create_allowed=create_allowed)
         self.pyl_analyzer = PyLucene.StandardAnalyzer()
@@ -171,7 +173,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         """generate a query based on an existing query object
 
         basically this function should just create a copy of the original
-        
+
         @param query: the original query object
         @type query: PyLucene.Query
         @return: resulting query object
@@ -280,7 +282,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
         @rtype: PyLucene.Document
         """
         return PyLucene.Document()
-    
+
     def _add_plain_term(self, document, term, tokenize=True):
         """add a term to a document
 
@@ -359,7 +361,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
 
     def get_query_result(self, query):
         """return an object containing the results of a query
-        
+
         @param query: a pre-compiled query
         @type query: a query object of the real implementation
         @return: an object that allows access to the results
@@ -422,7 +424,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
                     self.reader.unlock(self.reader.directory())
             except:
                 pass
-    
+
     def _writer_open(self):
         """open write access for the indexing database and acquire an
         exclusive lock
@@ -462,7 +464,7 @@ class PyLuceneDatabase(CommonIndexer.CommonDatabase):
                 self.reader = PyLucene.IndexReader.open(self.location)
                 self.searcher = PyLucene.IndexSearcher(self.reader)
                 self.index_version = self.reader.getCurrentVersion(self.location)
-        except PyLucene.JavaError,e:
+        except PyLucene.JavaError, e:
             # TODO: add some debugging output?
             #self.errorhandler.logerror("Error attempting to read index - try reindexing: "+str(e))
             pass
@@ -503,16 +505,16 @@ class PyLuceneHits(CommonIndexer.CommonEnquire):
         return (stop-start, self.enquire.length(), result)
 
 def _occur(required, prohibited):
-       if required == True and prohibited == False:
-           return PyLucene.BooleanClause.Occur.MUST
-       elif required == False and prohibited == False:
-           return PyLucene.BooleanClause.Occur.SHOULD
-       elif required == False and prohibited == True:
-           return PyLucene.BooleanClause.Occur.MUST_NOT
-       else:
-           # It is an error to specify a clause as both required
-           # and prohibited
-           return None
+    if required == True and prohibited == False:
+        return PyLucene.BooleanClause.Occur.MUST
+    elif required == False and prohibited == False:
+        return PyLucene.BooleanClause.Occur.SHOULD
+    elif required == False and prohibited == True:
+        return PyLucene.BooleanClause.Occur.MUST_NOT
+    else:
+        # It is an error to specify a clause as both required
+        # and prohibited
+        return None
 
 def _get_pylucene_version():
     """get the installed pylucene version
