@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2008 Zuza Software Foundation
+# Copyright 2008-2009 Zuza Software Foundation
 # 
 # This file is part of translate.
 #
@@ -21,7 +21,7 @@
 #
 
 """
-interface to the xapian indexing engine for the translate toolkit
+Interface to the Xapian indexing engine for the Translate Toolkit
 
 Xapian v1.0 or higher is supported.
 
@@ -31,13 +31,31 @@ you should checkout the following::
 It is not completely working, but it should give you a good start.
 """
 
-__revision__ = "$Id: XapianIndexer.py 8504 2008-09-27 09:02:29Z dwaynebailey $"
+__revision__ = "$Id: XapianIndexer.py 13411 2009-11-30 20:51:48Z alaaosh $"
 
+# xapian module versions before 1.0.13 hangs apache under mod_python
+import sys
+import re
+
+# detect if running under apache
+if 'apache' in sys.modules or '_apache' in sys.modules or 'mod_wsgi' in sys.modules:
+    def _str2version(version):
+        return [int(i) for i in version.split('.')]
+    
+    import subprocess
+    # even checking xapian version leads to deadlock under apache, must figure version from command line
+    try:
+        command = subprocess.Popen(['xapian-check', '--version'], stdout=subprocess.PIPE)
+        stdout, stderr = command.communicate()
+        if _str2version(re.match('.*([0-9]+\.[0-9]+\.[0-9]+).*', stdout).groups()[0]) < [1, 0, 13]:
+            raise ImportError("Running under apache, can't load xapain")
+    except:
+        #FIXME: report is xapian-check command is missing?
+        raise ImportError("Running under apache, can't load xapian")
 
 import CommonIndexer
 import xapian
 import os
-import re
 
 
 def is_available():
@@ -125,7 +143,7 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
         """generate a query based on an existing query object
 
         basically this function should just create a copy of the original
-        
+
         @param query: the original query object
         @type query: xapian.Query
         @return: the resulting query object
@@ -235,7 +253,7 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
         @rtype: xapian.Document
         """
         return xapian.Document()
-    
+
     def _add_plain_term(self, document, term, tokenize=True):
         """add a term to a document
 
@@ -310,7 +328,7 @@ class XapianDatabase(CommonIndexer.CommonDatabase):
 
     def get_query_result(self, query):
         """return an object containing the results of a query
-        
+
         @param query: a pre-compiled xapian query
         @type query: xapian.Query
         @return: an object that allows access to the results
@@ -416,7 +434,7 @@ def _truncate_term_length(term, taken=0):
 
 def _extract_fieldvalues(match, (result, fieldnames)):
     """add a dict of field values to a list
-    
+
     usually this function should be used together with '_walk_matches'
     for traversing a list of matches
     @param match: a single match object
@@ -443,4 +461,3 @@ def _extract_fieldvalues(match, (result, fieldnames)):
             else:
                 item_fields[fname] = [value]
     result.append(item_fields)
-
