@@ -27,7 +27,7 @@
 
 try:
     import cPickle as pickle
-except:
+except ImportError:
     import pickle
 from exceptions import NotImplementedError
 import translate.i18n
@@ -35,6 +35,7 @@ from translate.storage.placeables import StringElem, general, parse as rich_pars
 from translate.misc.typecheck import accepts, Self, IsOneOf
 from translate.misc.multistring import multistring
 
+
 def force_override(method, baseclass):
     """Forces derived classes to override method."""
 
@@ -51,6 +52,7 @@ def force_override(method, baseclass):
 
 
 class ParseError(Exception):
+
     def __init__(self, inner_exc):
         self.inner_exc = inner_exc
 
@@ -106,6 +108,15 @@ class TranslationUnit(object):
         """
         return self.source == other.source and self.target == other.target
 
+    def __str__(self):
+        """Converts to a string representation that can be parsed back using L{parsestring()}."""
+        # no point in pickling store object, so let's hide it for a while.
+        store = getattr(self, "_store", None)
+        self._store = None
+        dump = pickle.dumps(self)
+        self._store = store
+        return dump
+
     def rich_to_multistring(cls, elem_list):
         """Convert a "rich" string tree to a C{multistring}:
 
@@ -117,7 +128,7 @@ class TranslationUnit(object):
         return multistring([unicode(elem) for elem in elem_list])
     rich_to_multistring = classmethod(rich_to_multistring)
 
-    def multistring_to_rich(cls, mulstring):
+    def multistring_to_rich(self, mulstring):
         """Convert a multistring to a list of "rich" string trees:
 
            >>> target = multistring([u'foo', u'bar', u'baz'])
@@ -127,8 +138,8 @@ class TranslationUnit(object):
             <StringElem([<StringElem([u'baz'])>])>]
         """
         if isinstance(mulstring, multistring):
-            return [rich_parse(s, cls.rich_parsers) for s in mulstring.strings]
-        return [rich_parse(mulstring, cls.rich_parsers)]
+            return [rich_parse(s, self.rich_parsers) for s in mulstring.strings]
+        return [rich_parse(mulstring, self.rich_parsers)]
 
     def setsource(self, source):
         """Sets the source string to the given value."""
@@ -146,6 +157,7 @@ class TranslationUnit(object):
         if self._rich_source is None:
             self._rich_source = self.multistring_to_rich(self.source)
         return self._rich_source
+
     def _set_rich_source(self, value):
         if not hasattr(value, '__iter__'):
             raise ValueError('value must be iterable')
@@ -154,7 +166,9 @@ class TranslationUnit(object):
         if not isinstance(value[0], StringElem):
             raise ValueError('value[0] must be of type StringElem.')
         self._rich_source = list(value)
-        self.source = self.rich_to_multistring(value)
+        multi = self.rich_to_multistring(value)
+        if self.source != multi:
+            self.source = multi
     rich_source = property(_get_rich_source, _set_rich_source)
     """ @see: rich_to_multistring
         @see: multistring_to_rich"""
@@ -163,6 +177,7 @@ class TranslationUnit(object):
         if self._rich_target is None:
             self._rich_target = self.multistring_to_rich(self.target)
         return self._rich_target
+
     def _set_rich_target(self, value):
         if not hasattr(value, '__iter__'):
             raise ValueError('value must be iterable')
@@ -199,6 +214,13 @@ class TranslationUnit(object):
         """
         return self.source
 
+    def setid(self, value):
+        """Sets the unique identified for this unit.
+
+        only implemented if format allows ids independant from other
+        unit properties like source or context"""
+        pass
+
     def getlocations(self):
         """A list of source code locations.
 
@@ -231,6 +253,10 @@ class TranslationUnit(object):
         """Get the message context."""
         return ""
 
+    def setcontext(self, context):
+        """Set the message context"""
+        pass
+
     def getnotes(self, origin=None):
         """Returns all notes about this unit.
 
@@ -240,7 +266,7 @@ class TranslationUnit(object):
         """
         return getattr(self, "notes", "")
 
-    def addnote(self, text, origin=None):
+    def addnote(self, text, origin=None, position="append"):
         """Adds a note (comment).
 
         @type text: string
@@ -251,8 +277,8 @@ class TranslationUnit(object):
                          - 'translator'
                          - 'developer', 'programmer', 'source code' (synonyms)
         """
-        if getattr(self, "notes", None):
-            self.notes += '\n'+text
+        if position == "append" and getattr(self, "notes", None):
+            self.notes += '\n' + text
         else:
             self.notes = text
 
@@ -345,7 +371,7 @@ class TranslationUnit(object):
     def gettargetlanguage(self):
         return getattr(self._store, "targetlanguage", None)
 
-    def merge(self, otherunit, overwrite=False, comments=True):
+    def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
         """Do basic format agnostic merging."""
         if not self.target or overwrite:
             self.rich_target = otherunit.rich_target
@@ -469,7 +495,6 @@ class TranslationStore(object):
                     return unit
         return None
 
-
     def findunits(self, source):
         """Finds the units with the given source string.
 
@@ -501,6 +526,7 @@ class TranslationStore(object):
 
     def remove_unit_from_index(self, unit):
         """Remove a unit from source and locaton indexes"""
+
         def remove_unit(source):
             if source in self.sourceindex:
                 try:
@@ -521,7 +547,6 @@ class TranslationStore(object):
                    and self.locationindex[location] == unit:
                 del(self.locationindex[location])
 
-
     def add_unit_to_index(self, unit):
         """Add a unit to source and location idexes"""
         self.id_index[unit.getid()] = unit
@@ -558,10 +583,10 @@ class TranslationStore(object):
 
     def require_index(self):
         """make sure source index exists"""
-        if not hasattr(self, "sourceindex"):
+        if not hasattr(self, "id_index"):
             self.makeindex()
 
-    def getids(self):
+    def getids(self, filename=None):
         """return a list of unit ids"""
         self.require_index()
         return self.id_index.keys()
