@@ -28,6 +28,7 @@ import csv
 from translate.misc import sparse
 from translate.storage import base
 
+
 class SimpleDictReader:
     def __init__(self, fileobj, fieldnames):
         self.fieldnames = fieldnames
@@ -88,6 +89,7 @@ class SimpleDictReader:
                 values[self.fieldnames[fieldnum]] = fields[fieldnum]
         return values
 
+
 class csvunit(base.TranslationUnit):
     spreadsheetescapes = [("+", "\\+"), ("-", "\\-"), ("=", "\\="), ("'", "\\'")]
     def __init__(self, source=None):
@@ -115,12 +117,15 @@ class csvunit(base.TranslationUnit):
         return source, target
 
     def fromdict(self, cedict):
-        self.comment = cedict.get('comment', '').decode('utf-8')
+        self.comment = cedict.get('location', '').decode('utf-8')
         self.source = cedict.get('source', '').decode('utf-8')
         self.target = cedict.get('target', '').decode('utf-8')
-        if self.comment is None: self.comment = ''
-        if self.source is None: self.source = ''
-        if self.target is None: self.target = ''
+        if self.comment is None:
+            self.comment = ''
+        if self.source is None:
+            self.source = ''
+        if self.target is None:
+            self.target = ''
         self.source, self.target = self.remove_spreadsheet_escapes(self.source, self.target)
 
     def todict(self, encoding='utf-8'):
@@ -132,20 +137,20 @@ class csvunit(base.TranslationUnit):
             source = source.encode(encoding)
         if isinstance(target, unicode):
             target = target.encode(encoding)
-        return {'comment':comment, 'source': source, 'target': target}
+        return {'location': comment, 'source': source, 'target': target}
 
 class csvfile(base.TranslationStore):
     """This class represents a .csv file with various lines. 
-    The default format contains three columns: comments, source, target"""
+    The default format contains three columns: location, source, target"""
     UnitClass = csvunit
-    Name = _("Comma Seperated Value")
-    Mimetypes  = ['text/comma-separated-values', 'text/csv']
+    Name = _("Comma Separated Value")
+    Mimetypes = ['text/comma-separated-values', 'text/csv']
     Extensions = ["csv"]
     def __init__(self, inputfile=None, fieldnames=None):
-        base.TranslationStore.__init__(self, unitclass = self.UnitClass)
+        base.TranslationStore.__init__(self, unitclass=self.UnitClass)
         self.units = []
         if fieldnames is None:
-            self.fieldnames = ['comment', 'source', 'target']
+            self.fieldnames = ['location', 'source', 'target']
         else:
             if isinstance(fieldnames, basestring):
                 fieldnames = [fieldname.strip() for fieldname in fieldnames.split(",")]
@@ -179,4 +184,3 @@ class csvfile(base.TranslationStore):
             writer.writerow(cedict)
         csvfile.reset()
         return "".join(csvfile.readlines())
-
