@@ -30,7 +30,8 @@ directly, but can be used once cpo has been established to work."""
 
 from translate.misc.multistring import multistring
 from translate.lang import data
-from translate.storage import pocommon, base, cpo
+from translate.storage import pocommon, base, cpo, poparser
+from translate.storage.pocommon import encodingToUse
 import re
 import copy
 import cStringIO
@@ -44,13 +45,6 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 '''
 
-def encodingToUse(encoding):
-    """Tests whether the given encoding is known in the python runtime, or returns utf-8.
-    This function is used to ensure that a valid encoding is always used."""
-    if encoding == "CHARSET" or encoding == None:
-        return 'utf-8'
-    return encoding
-
 class pounit(pocommon.pounit):
     # othercomments = []      #   # this is another comment
     # automaticcomments = []  #   #. comment extracted from the source code
@@ -134,7 +128,7 @@ class pounit(pocommon.pounit):
             comments = u"\n".join(self.othercomments)
             comments += u"\n".join(self.automaticcomments)
         elif origin == "translator":
-            comments = u"\n".join (self.othercomments)
+            comments = u"\n".join(self.othercomments)
         elif origin in ["programmer", "developer", "source code"]:
             comments = u"\n".join(self.automaticcomments)
         else:
@@ -148,21 +142,22 @@ class pounit(pocommon.pounit):
             return
         text = data.forceunicode(text)
         commentlist = self.othercomments
+        autocomments = False
         if origin in ["programmer", "developer", "source code"]:
             autocomments = True
             commentlist = self.automaticcomments
         if text.endswith(u'\n'):
             text = text[:-1]
-        text = text.split(u"\n")
+        newcomments = text.split(u"\n")
         if position == "append":
-            commentlist.extend(text)
+            newcomments = commentlist + newcomments
+        elif position == "prepend":
+            newcomments = newcomments + commentlist
+
+        if autocomments:
+            self.automaticcomments = newcomments
         else:
-            newcomments = text
-            newcomments.extend(commentlist)
-            if autocomments:
-                self.automaticcomments = newcomments
-            else:
-                self.othercomments = newcomments
+            self.othercomments = newcomments
 
     def removenotes(self):
         """Remove all the translator's notes (other comments)"""
@@ -192,15 +187,15 @@ class pounit(pocommon.pounit):
 
     def _msgidlen(self):
         if self.hasplural():
-            len("".join([string.strip() for string in self.source.strings]))
+            len("".join([string for string in self.source.strings]))
         else:
-            return len(self.source.strip())
+            return len(self.source)
 
     def _msgstrlen(self):
         if self.hasplural():
-            len("".join([string.strip() for string in self.target.strings]))
+            len("".join([string for string in self.target.strings]))
         else:
-            return len(self.target.strip())
+            return len(self.target)
 
     def merge(self, otherpo, overwrite=False, comments=True, authoritative=False):
         """Merges the otherpo (with the same msgid) into this one.
@@ -415,17 +410,6 @@ class pofile(pocommon.pofile):
     """A .po file containing various units"""
     UnitClass = pounit
 
-    def __init__(self, inputfile=None, encoding=None, unitclass=pounit):
-        """Construct a pofile, optionally reading in from inputfile.
-        encoding can be specified but otherwise will be read from the PO header"""
-        self.UnitClass = unitclass
-        pocommon.pofile.__init__(self, unitclass=unitclass)
-        self.units = []
-        self.filename = ''
-        self._encoding = encodingToUse(encoding)
-        if inputfile is not None:
-            self.parse(inputfile)
-
     def changeencoding(self, newencoding):
         """Deprecated: changes the encoding on the file."""
         # This should not be here but in poheader. It also shouldn't mangle the
@@ -497,6 +481,7 @@ class pofile(pocommon.pofile):
 #            if isinstance(input, str) and '"Content-Type: text/plain; charset=' not in input[:200]:
 #                input = basic_header + input
 #                tmp_header_added = True
+            self.units = []
             self._cpo_store = cpo.pofile(input)
             self._build_self_from_cpo()
             del self._cpo_store
