@@ -26,7 +26,7 @@ from translate.storage import base
 from translate.lang import data
 try:
     from lxml import etree
-    from translate.misc.xml_helpers import *
+    from translate.misc.xml_helpers import getText, getXMLlang, setXMLlang, getXMLspace, setXMLspace, namespaced
 except ImportError, e:
     raise ImportError("lxml is not installed. It might be possible to continue without support for XML formats.")
 
@@ -77,11 +77,11 @@ class LISAunit(base.TranslationUnit):
 
     def __init__(self, source, empty=False, **kwargs):
         """Constructs a unit containing the given source string"""
+        self._rich_source = None
+        self._rich_target = None
         if empty:
-            self._rich_source = None
-            self._rich_target = None
             return
-        self.xmlelement = etree.Element(self.rootNode)
+        self.xmlelement = etree.Element(self.namespaced(self.rootNode))
         #add descrip, note, etc.
         super(LISAunit, self).__init__(source)
 
@@ -113,7 +113,7 @@ class LISAunit(base.TranslationUnit):
     def set_source_dom(self, dom_node):
         languageNodes = self.getlanguageNodes()
         if len(languageNodes) > 0:
-            self.xmlelement[0] = dom_node
+            self.xmlelement.replace(languageNodes[0], dom_node)
         else:
             self.xmlelement.append(dom_node)
 
@@ -122,6 +122,8 @@ class LISAunit(base.TranslationUnit):
     source_dom = property(get_source_dom, set_source_dom)
 
     def setsource(self, text, sourcelang='en'):
+        if self._rich_source is not None:
+            self._rich_source = None
         text = data.forceunicode(text)
         self.source_dom = self.createlanguageNode(sourcelang, text, "source")
 
@@ -148,9 +150,11 @@ class LISAunit(base.TranslationUnit):
     target_dom = property(get_target_dom)
 
     def settarget(self, text, lang='xx', append=False):
+        """Sets the "target" string (second language), or alternatively appends to the list"""
         #XXX: we really need the language - can't really be optional, and we
         # need to propagate it
-        """Sets the "target" string (second language), or alternatively appends to the list"""
+        if self._rich_target is not None:
+            self._rich_target = None
         text = data.forceunicode(text)
         #Firstly deal with reinitialising to None or setting to identical string
         if self.gettarget() == text:
@@ -202,7 +206,7 @@ class LISAunit(base.TranslationUnit):
             if pretext:
                 lasttag.tail = pretext
             #ph node
-            phnode = etree.SubElement(parent, "ph")
+            phnode = etree.SubElement(parent, self.namespaced("ph"))
             phnode.set("id", str(i+1))
             phnode.text = m.group()
             lasttag = phnode
@@ -341,7 +345,7 @@ class LISAfile(base.TranslationStore):
         self._encoding = self.document.docinfo.encoding
         self.initbody()
         assert self.document.getroot().tag == self.namespaced(self.rootNode)
-        for entry in self.body.iterdescendants(self.namespaced(self.UnitClass.rootNode)):
+        for entry in self.document.getroot().iterdescendants(self.namespaced(self.UnitClass.rootNode)):
             term = self.UnitClass.createfromxmlElement(entry)
             self.addunit(term, new=False)
 
