@@ -24,7 +24,7 @@ Classes that hold units of .oo files (oounit) or entire files (oofile).
 
 These are specific .oo files for localisation exported by OpenOffice.org - SDF 
 format (previously knows as GSI files). For an overview of the format, see
-http://l10n.openoffice.org/L10N_Framework/Intermediate_file_format.html
+U{http://l10n.openoffice.org/L10N_Framework/Intermediate_file_format.html}
 
 The behaviour in terms of escaping is explained in detail in the programming
 comments.
@@ -33,7 +33,6 @@ comments.
 
 import os
 import re
-import sys
 from translate.misc import quote
 from translate.misc import wStringIO
 import warnings
@@ -65,6 +64,32 @@ def normalizefilename(filename):
     else:
         return filename.translate(unormalizetable)
 
+def makekey(ookey, long_keys):
+    """converts an oo key tuple into a unique identifier
+
+    @param ookey: an oo key
+    @type ookey: tuple
+    @param long_keys: Use long keys
+    @type long_keys: Boolean
+    @rtype: str
+    @return: unique ascii identifier
+    """
+    project, sourcefile, resourcetype, groupid, localid, platform = ookey
+    sourcefile = sourcefile.replace('\\','/')
+    if long_keys:
+        sourcebase = os.path.join(project, sourcefile)
+    else:
+        sourceparts = sourcefile.split('/')
+        sourcebase = "".join(sourceparts[-1:])
+    if len(groupid) == 0 or len(localid) == 0:
+        fullid = groupid + localid
+    else:
+        fullid = groupid + "." + localid
+    if resourcetype:
+        fullid = fullid + "." + resourcetype
+    key = "%s#%s" % (sourcebase, fullid)
+    return normalizefilename(key)
+
 # These are functions that deal with escaping and unescaping of the text fields
 # of the SDF file. These should only be applied to the text column. 
 # The fields quickhelptext and title are assumed to carry no escaping.
@@ -105,12 +130,12 @@ def escape_help_text(text):
     """
     text = text.replace("\\", "\\\\")
     for tag in helptagre.findall(text):
-        escapethistag = True
-        if tag in ["<br>", "<h1>", "</h1>", "<img ...>", "<->", "<empty>", "<ref>", "<references>"]:
-            escapethistag = False
-        for skip in ["<font", "<node", "<help_section"]:
-            if tag.startswith(skip):
-                escapethistag = False
+        escapethistag = False
+        for escape_tag in ["ahelp", "link", "item", "emph", "defaultinline", "switchinline", "caseinline", "variable", "bookmark_value", "image", "embedvar", "alt"]:
+            if tag.startswith("<%s" % escape_tag) or tag == "</%s>" % escape_tag:
+                escapethistag = True
+        if tag in ["<br/>", "<help-id-missing/>"]:
+            escapethistag = True
         if escapethistag:
             escaped_tag = ("\\<" + tag[1:-1] + "\\>").replace('"', '\\"')
             text = text.replace(tag, escaped_tag)
@@ -363,7 +388,3 @@ class oomultifile:
         oosubfile.parse(subfilesrc)
         return oosubfile
 
-if __name__ == '__main__':
-    of = oofile()
-    of.parse(sys.stdin.read())
-    sys.stdout.write(str(of))
