@@ -23,8 +23,8 @@ Contains base placeable classes with names based on XLIFF placeables. See the
 XLIFF standard for more information about what the names mean.
 """
 
-from strelem import StringElem
-from interfaces import *
+from translate.storage.placeables.strelem import StringElem
+from translate.storage.placeables.interfaces import *
 
 
 __all__ = ['Bpt', 'Ept', 'Ph', 'It', 'G', 'Bx', 'Ex', 'X', 'Sub', 'to_base_placeables']
