@@ -82,12 +82,39 @@ class pounit(base.TranslationUnit):
     def istranslatable(self):
         return not (self.isheader() or self.isblank() or self.isobsolete())
 
+    def hasmarkedcomment(self, commentmarker):
+        raise NotImplementedError
+
     def isreview(self):
         return self.hasmarkedcomment("review") or self.hasmarkedcomment("pofilter")
 
 
+def encodingToUse(encoding):
+    """Tests whether the given encoding is known in the python runtime, or returns utf-8.
+    This function is used to ensure that a valid encoding is always used."""
+    if encoding == "CHARSET" or encoding == None:
+        return 'utf-8'
+    return encoding
+#    if encoding is None: return False
+#    return True
+#    try:
+#        tuple = codecs.lookup(encoding)
+#    except LookupError:
+#        return False
+#    return True
+
 class pofile(poheader.poheader, base.TranslationStore):
-    Name = _("Gettext PO file")
+    Name = _("Gettext PO file") # pylint: disable-msg=E0602
     Mimetypes  = ["text/x-gettext-catalog", "text/x-gettext-translation", "text/x-po", "text/x-pot"]
     Extensions = ["po", "pot"]
 
+    def __init__(self, inputfile=None, encoding=None):
+        super(pofile, self).__init__(unitclass=self.UnitClass)
+        self.units = []
+        self.filename = ''
+        self._encoding = encodingToUse(encoding)
+        if inputfile is not None:
+            self.parse(inputfile)
+        else:
+            self.init_headers()
+
