@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# 
+#
 # Copyright 2004-2006 Zuza Software Foundation
-# 
+#
 # This file is part of translate.
 #
 # translate is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # translate is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -21,7 +21,7 @@
 
 """classes that hold units of .properties files (propunit) or entire files
    (propfile) these files are used in translating Mozilla and other software
-   
+
    The following U{.properties file
    description<http://java.sun.com/j2se/1.4.2/docs/api/java/util/Properties.html#load(java.io.InputStream)>}
    and U{example <http://www.exampledepot.com/egs/java.util/Props.html>} give some
@@ -35,11 +35,11 @@
    Implementation
    ==============
    A simple summary of what is permissible follows.
-   
+
    Comments::
      # a comment
      ! a comment
-       
+
    Name and Value pairs::
      # Note that the b and c are escaped for epydoc rendering
      a = a string
@@ -59,47 +59,54 @@ import re
 
 eol = "\n"
 
-def find_delimeter(line):
-    """Find the type and position of the delimeter in a property line.
+def find_delimiter(line):
+    """Find the type and position of the delimiter in a property line.
 
     Property files can be delimeted by "=", ":" or whitespace (space for now).
-    We find the position of each delimeter, then find the one that appears 
+    We find the position of each delimiter, then find the one that appears 
     first.
 
     @param line: A properties line
     @type line: str
-    @return: Delimeter character and offset within L{line}
-    @rtype: Tuple (Delimeter char, Offset Integer)
+    @return: delimiter character and offset within L{line}
+    @rtype: Tuple (delimiter char, Offset Integer)
     """
-    delimeters = {"=": -1, ":": -1, " ": -1}
-    # Find the position of each delimeter type
-    for delimeter, pos in delimeters.iteritems():
+    delimiters = {"=": -1, ":": -1, " ": -1}
+    # Find the position of each delimiter type
+    for delimiter, pos in delimiters.iteritems():
         prewhitespace = len(line) - len(line.lstrip())
-        pos = line.find(delimeter, prewhitespace)
+        pos = line.find(delimiter, prewhitespace)
         while pos != -1:
-            if delimeters[delimeter] == -1 and line[pos-1] != "\\":
-                delimeters[delimeter] = pos
+            if delimiters[delimiter] == -1 and line[pos-1] != "\\":
+                delimiters[delimiter] = pos
                 break
-            pos = line.find(delimeter, pos+1)
-    # Find the first "=" or ":" delimeter
-    mindelimeter = None
+            pos = line.find(delimiter, pos+1)
+    # Find the first "=" or ":" delimiter
+    mindelimiter = None
     minpos = -1
-    for delimeter, pos in delimeters.iteritems():
-        if pos == -1 or delimeter == " ":
+    for delimiter, pos in delimiters.iteritems():
+        if pos == -1 or delimiter == " ":
             continue
         if minpos == -1 or pos < minpos:
             minpos = pos
-            mindelimeter = delimeter
-    if mindelimeter is None and delimeters[" "] != -1:
-        # Use space delimeter if we found nothing else
-        return (" ", delimeters[" "])
-    if mindelimeter is not None and delimeters[" "] < delimeters[mindelimeter]:
-        # If space delimeter occurs earlier then ":" or "=" then it is the 
-        # delimeter only if there are non-whitespace characters between it and
-        # the other detected delimeter.
-        if len(line[delimeters[" "]:delimeters[mindelimeter]].strip()) > 0:
-            return (" ", delimeters[" "])
-    return (mindelimeter, minpos)
+            mindelimiter = delimiter
+    if mindelimiter is None and delimiters[" "] != -1:
+        # Use space delimiter if we found nothing else
+        return (" ", delimiters[" "])
+    if mindelimiter is not None and delimiters[" "] < delimiters[mindelimiter]:
+        # If space delimiter occurs earlier then ":" or "=" then it is the 
+        # delimiter only if there are non-whitespace characters between it and
+        # the other detected delimiter.
+        if len(line[delimiters[" "]:delimiters[mindelimiter]].strip()) > 0:
+            return (" ", delimiters[" "])
+    return (mindelimiter, minpos)
+
+def find_delimeter(line):
+    """Spelling error that is kept around for in case someone relies on it.
+
+    Deprecated."""
+    raise DeprecationWarning
+    return find_delimiter(line)
 
 def is_line_continuation(line):
     """Determine whether L{line} has a line continuation marker.
@@ -150,12 +157,13 @@ class propunit(base.TranslationUnit):
         super(propunit, self).__init__(source)
         self.name = ""
         self.value = u""
-        self.delimeter = u"="
+        self.translation = u""
+        self.delimiter = u"="
         self.comments = []
         self.source = source
 
     def setsource(self, source):
-        """Sets the source AND the target to be equal"""
+        self._rich_source = None
         source = data.forceunicode(source)
         if self.personality == "mozilla" or self.personality == "skype":
             self.value = quote.mozillapropertiesencode(source or u"")
@@ -170,11 +178,18 @@ class propunit(base.TranslationUnit):
     source = property(getsource, setsource)
 
     def settarget(self, target):
-        """Note: this also sets the .source attribute!"""
-        self.source = target
+        self._rich_target = None
+        target = data.forceunicode(target)
+        if self.personality == "mozilla" or self.personality == "skype":
+            self.translation = quote.mozillapropertiesencode(target or u"")
+        else:
+            self.translation = quote.javapropertiesencode(target or u"")
 
     def gettarget(self):
-        return self.source
+        translation = quote.propertiesdecode(self.translation)
+        translation = re.sub(u"\\\\ ", u" ", translation)
+        return translation
+
     target = property(gettarget, settarget)
 
     def __str__(self):
@@ -194,17 +209,26 @@ class propunit(base.TranslationUnit):
         else:
             if "\\u" in self.value and self.personality == "mozilla":
                 self.value = quote.mozillapropertiesencode(self.source)
-            return u"%s%s%s%s\n" % (notes, self.name, self.delimeter, self.value)
+            if "\\u" in self.translation and self.personality == "mozilla":
+                self.translation = quote.mozillapropertiesencode(self.target)
+            value = self.translation or self.value
+            return u"%s%s%s%s\n" % (notes, self.name, self.delimiter, value)
 
     def getlocations(self):
         return [self.name]
 
-    def addnote(self, note, origin=None):
-        note = data.forceunicode(note)
-        self.comments.append(note)
+    def addnote(self, text, origin=None, position="append"):
+        if origin in ['programmer', 'developer', 'source code', None]:
+            text = data.forceunicode(text)
+            self.comments.append(text)
+        else:
+            return super(propunit, self).addnote(text, origin=origin, position=position)
 
     def getnotes(self, origin=None):
-        return u'\n'.join(self.comments)
+        if origin in ['programmer', 'developer', 'source code', None]:
+            return u'\n'.join(self.comments)
+        else:
+            return super(propunit, self).getnotes(origin)
 
     def removenotes(self):
         self.comments = []
@@ -213,6 +237,12 @@ class propunit(base.TranslationUnit):
         """returns whether this is a blank element, containing only comments..."""
         return not (self.name or self.value)
 
+    def istranslatable(self):
+        return bool(self.name)
+
+    def getid(self):
+        return self.name
+
 class propfile(base.TranslationStore):
     """this class represents a .properties file, made up of propunits"""
     UnitClass = propunit
@@ -255,14 +285,14 @@ class propfile(base.TranslationStore):
                     self.addunit(newunit)
                     newunit = propunit("", personality)
             else:
-                delimeter_char, delimeter_pos = find_delimeter(line)
-                if delimeter_pos == -1:
+                delimiter_char, delimiter_pos = find_delimiter(line)
+                if delimiter_pos == -1:
                     continue
                 # otherwise, this is a definition
                 else:
-                    newunit.delimeter = delimeter_char
-                    newunit.name = key_strip(line[:delimeter_pos])
-                    newunit.value = line[delimeter_pos+1:].lstrip()
+                    newunit.delimiter = delimiter_char
+                    newunit.name = key_strip(line[:delimiter_pos])
+                    newunit.value = line[delimiter_pos+1:].lstrip()
                     # backslash at end means carry string on to next line
                     if is_line_continuation(newunit.value):
                         inmultilinevalue = True
