@@ -26,11 +26,11 @@ from translate.misc.multistring import multistring
 from translate.misc import quote
 from translate.misc import textwrap
 from translate.lang import data
-from translate.storage import pocommon, base
+from translate.storage import pocommon, base, poparser
+from translate.storage.pocommon import encodingToUse
 import re
 import copy
 import cStringIO
-import poparser
 
 lsep = "\n#: "
 """Seperator for #: entries"""
@@ -112,20 +112,6 @@ def extractpoline(line):
 def unquotefrompo(postr):
     return u"".join([extractpoline(line) for line in postr])
 
-def encodingToUse(encoding):
-    """Tests whether the given encoding is known in the python runtime, or returns utf-8.
-    This function is used to ensure that a valid encoding is always used."""
-    if encoding == "CHARSET" or encoding == None:
-        return 'utf-8'
-    return encoding
-#    if encoding is None: return False
-#    return True
-#    try:
-#        tuple = codecs.lookup(encoding)
-#    except LookupError:
-#        return False
-#    return True
-
 def is_null(lst):
     return lst == [] or len(lst) == 1 and lst[0] == '""'
 
@@ -229,6 +215,7 @@ class pounit(pocommon.pounit):
 
         @param source: an unescaped source string.
         """
+        self._rich_source = None
         self.msgid, self.msgid_plural = self._set_source_vars(source)
     source = property(getsource, setsource)
 
@@ -306,15 +293,16 @@ class pounit(pocommon.pounit):
             commentlist = self.automaticcomments
             linestart = "#. "
         text = text.split("\n")
+        newcomments = [linestart + line + "\n" for line in text]
         if position == "append":
-            commentlist += [linestart + line + "\n" for line in text]
+            newcomments = commentlist + newcomments
+        elif position == "prepend":
+            newcomments = newcomments + commentlist
+
+        if autocomments:
+            self.automaticcomments = newcomments
         else:
-            newcomments = [linestart + line + "\n" for line in text]
-            newcomments += [line for line in commentlist]
-            if autocomments:
-                self.automaticcomments = newcomments
-            else:
-                self.othercomments = newcomments
+            self.othercomments = newcomments
 
     def removenotes(self):
         """Remove all the translator's notes (other comments)"""
@@ -344,16 +332,16 @@ class pounit(pocommon.pounit):
 
     def _msgidlen(self):
         if self.hasplural():
-            return len(unquotefrompo(self.msgid).strip()) + len(unquotefrompo(self.msgid_plural).strip())
+            return len(unquotefrompo(self.msgid)) + len(unquotefrompo(self.msgid_plural))
         else:
-            return len(unquotefrompo(self.msgid).strip())
+            return len(unquotefrompo(self.msgid))
 
     def _msgstrlen(self):
         if isinstance(self.msgstr, dict):
-            combinedstr = "\n".join([unquotefrompo(msgstr).strip() for msgstr in self.msgstr.itervalues()])
-            return len(combinedstr.strip())
+            combinedstr = "\n".join([unquotefrompo(msgstr) for msgstr in self.msgstr.itervalues()])
+            return len(combinedstr)
         else:
-            return len(unquotefrompo(self.msgstr).strip())
+            return len(unquotefrompo(self.msgstr))
 
     def merge(self, otherpo, overwrite=False, comments=True, authoritative=False):
         """Merges the otherpo (with the same msgid) into this one.
@@ -468,7 +456,11 @@ class pounit(pocommon.pounit):
         """Alters whether a given typecomment is present"""
         if self.hastypecomment(typecomment) != present:
             if present:
-                self.typecomments.append("#, %s\n" % typecomment)
+                if len(self.typecomments):
+                    # There is already a comment, so we have to add onto it
+                    self.typecomments[0] = "%s, %s\n" % (self.typecomments[0][:-1], typecomment)
+                else:
+                    self.typecomments.append("#, %s\n" % typecomment)
             else:
                 # this should handle word boundaries properly ...
                 typecomments = map(lambda tcline: re.sub("\\b%s\\b[ \t,]*" % typecomment, "", tcline), self.typecomments)
@@ -671,7 +663,7 @@ class pounit(pocommon.pounit):
             self.msgidcomments = []
 
     msgidcomment = property(_extract_msgidcomments, setmsgidcomment)
-    
+
     def getcontext(self):
         """Get the message context."""
         return unquotefrompo(self.msgctxt) + self._extract_msgidcomments()
@@ -695,54 +687,6 @@ class pofile(pocommon.pofile):
     """A .po file containing various units"""
     UnitClass = pounit
 
-    def __init__(self, inputfile=None, encoding=None, unitclass=pounit):
-        """Construct a pofile, optionally reading in from inputfile.
-        encoding can be specified but otherwise will be read from the PO header"""
-        self.UnitClass = unitclass
-        pocommon.pofile.__init__(self, unitclass=unitclass)
-        self.units = []
-        self.filename = ''
-        self._encoding = encodingToUse(encoding)
-        if inputfile is not None:
-            self.parse(inputfile)
-
-    def changeencoding(self, newencoding):
-        """Deprecated: changes the encoding on the file."""
-        # This should not be here but in poheader. It also shouldn't mangle the
-        # header itself, but use poheader methods. All users are removed, so
-        # we can deprecate after one release.
-        raise DeprecationWarning
-
-        self._encoding = encodingToUse(newencoding)
-        if not self.units:
-            return
-        header = self.header()
-        if not header or header.isblank():
-            return
-        charsetline = None
-        headerstr = unquotefrompo(header.msgstr)
-        for line in headerstr.split("\n"):
-            if not ":" in line:
-                continue
-            key, value = line.strip().split(":", 1)
-            if key.strip() != "Content-Type":
-                continue
-            charsetline = line
-        if charsetline is None:
-            headerstr += "Content-Type: text/plain; charset=%s" % self._encoding
-        else:
-            charset = re.search("charset=([^ ]*)", charsetline)
-            if charset is None:
-                newcharsetline = charsetline
-                if not newcharsetline.strip().endswith(";"):
-                    newcharsetline += ";"
-                newcharsetline += " charset=%s" % self._encoding
-            else:
-                charset = charset.group(1)
-                newcharsetline = charsetline.replace("charset=%s" % charset, "charset=%s" % self._encoding, 1)
-            headerstr = headerstr.replace(charsetline, newcharsetline, 1)
-        header.msgstr = quoteforpo(headerstr)
-
     def parse(self, input):
         """Parses the given file or file source string."""
         try:
@@ -752,6 +696,8 @@ class pofile(pocommon.pofile):
                 self.filename = ''
             if isinstance(input, str):
                 input = cStringIO.StringIO(input)
+            # clear units to get rid of automatically generated headers before parsing
+            self.units = []
             poparser.parse_units(poparser.ParseState(input, pounit), self)
         except Exception, e:
             raise base.ParseError(e)
