@@ -46,7 +46,7 @@ def escape_to_rc(string):
 
 class rcunit(base.TranslationUnit):
     """A unit of an rc file"""
-    def __init__(self, source=""):
+    def __init__(self, source="", encoding="cp1252"):
         """Construct a blank rcunit."""
         super(rcunit, self).__init__(source)
         self.name = ""
@@ -54,9 +54,11 @@ class rcunit(base.TranslationUnit):
         self.comments = []
         self.source = source
         self.match = None
+        self.encoding = encoding
 
     def setsource(self, source):
         """Sets the source AND the target to be equal"""
+        self._rich_source = None
         self._value = source or ""
 
     def getsource(self):
@@ -66,6 +68,7 @@ class rcunit(base.TranslationUnit):
 
     def settarget(self, target):
         """Note: this also sets the .source attribute!"""
+        self._rich_target = None
         self.source = target
 
     def gettarget(self):
@@ -89,7 +92,7 @@ class rcunit(base.TranslationUnit):
     def getlocations(self):
         return [self.name]
 
-    def addnote(self, note, origin=None):
+    def addnote(self, text, origin=None, position="append"):
         self.comments.append(note)
 
     def getnotes(self, origin=None):
@@ -105,14 +108,15 @@ class rcunit(base.TranslationUnit):
 class rcfile(base.TranslationStore):
     """This class represents a .rc file, made up of rcunits."""
     UnitClass = rcunit
-    def __init__(self, inputfile=None, lang=None, sublang=None):
+    def __init__(self, inputfile=None, lang=None, sublang=None, encoding="cp1252"):
         """Construct an rcfile, optionally reading in from inputfile."""
+        self.encoding = encoding
         super(rcfile, self).__init__(unitclass = self.UnitClass)
         self.filename = getattr(inputfile, 'name', '')
         self.lang = lang
         self.sublang = sublang
         if inputfile is not None:
-            rcsrc = inputfile.read()
+            rcsrc = inputfile.read().decode(encoding)
             inputfile.close()
             self.parse(rcsrc)
 
