@@ -360,6 +360,8 @@ class StatsCache(object):
 
         store can be a TranslationFile object or a callback that returns one.
         """
+        if isinstance(filename, str):
+            filename = unicode(filename, sys.getfilesystemencoding())
         realpath = os.path.realpath(filename)
         self.cur.execute("""SELECT fileid, st_mtime, st_size FROM files
                 WHERE path=?;""", (realpath,))
