@@ -6,7 +6,11 @@ from translate.storage.directory import Directory
 from translate.misc import wStringIO
 
 from gzip import GzipFile
-from bz2 import BZ2File
+try:
+    # bz2 is not available on python 2.3
+    from bz2 import BZ2File
+except ImportError:
+    BZ2File = None
 import os
 
 def classname(filename):
@@ -104,6 +108,8 @@ class BaseTestFactory:
 
     def test_bz2file(self):
         """Test that we can open a gzip file correctly."""
+        if not BZ2File:
+            return
         filename = os.path.join(self.testdir, self.filename + '.bz2')
         bz2file = BZ2File(filename, mode="wb")
         bz2file.write(self.file_content)
@@ -151,3 +157,9 @@ Content-Type: text/plain; charset=UTF-8
 Content-Transfer-Encoding: 8bit
 </target>
 </trans-unit></body></file></xliff>'''
+
+class TestWordfastFactory(BaseTestFactory):
+    expected_instance = factory.wordfast.WordfastTMFile
+    filename = 'dummy.txt'
+    file_content = '''%20070801~103212	%User ID,S,S SMURRAY,SMS Samuel Murray-Smit,SM Samuel Murray-Smit,MW Mary White,DS Deepak Shota,MT! Machine translation (15),AL! Alignment (10),SM Samuel Murray,	%TU=00000075	%AF-ZA	%Wordfast TM v.5.51r/00	%EN-ZA	%---80597535	Subject (5),EL,EL Electronics,AC Accounting,LE Legal,ME Mechanics,MD Medical,LT Literary,AG Agriculture,CO Commercial	Client (5),LS,LS LionSoft Corp,ST SuperTron Inc,CA CompArt Ltd			
+20070801~103248	SM	0	AF-ZA	Langeraad en duimpie	EN-ZA	Big Ben and Little John	EL	LS'''
