@@ -27,6 +27,9 @@ class TestPOUnit(test_base.TestTranslationUnit):
         unit = self.UnitClass("Message")
         assert unit.istranslatable()
 
+        unit.source = " "
+        assert unit.istranslatable()
+
         unit.source = ""
         assert not unit.istranslatable()
         # simulate a header
@@ -41,8 +44,9 @@ class TestPOUnit(test_base.TestTranslationUnit):
 
     def test_adding_empty_note(self):
         unit = self.UnitClass("bla")
+        print str(unit)
         assert not '#' in str(unit)
-        for empty_string in [ "", " ", "\t", "\n" ]:
+        for empty_string in ["", " ", "\t", "\n"]:
             unit.addnote(empty_string)
             assert not '#' in str(unit)
 
@@ -256,7 +260,7 @@ msgstr[1] "Kóeie"
         unit = pofile.units[0]
         assert isinstance(unit.source, multistring)
         assert isinstance(unit.source.strings[1], unicode)
-        
+
 
     def wtest_kde_plurals(self):
         """Tests kde-style plurals. (Bug: 191)"""
@@ -305,12 +309,16 @@ msgstr "POT-Creation-Date: 2006-03-08 17:30+0200\n"
 
         posource = '#, fuzzy, python-format\nmsgid "ball"\nmsgstr "bal"\n'
         expectednonfuzzy = '#, python-format\nmsgid "ball"\nmsgstr "bal"\n'
+        expectedfuzzyagain = '#, python-format, fuzzy\nmsgid "ball"\nmsgstr "bal"\n'
         pofile = self.poparse(posource)
         print pofile
         assert pofile.units[0].isfuzzy()
         pofile.units[0].markfuzzy(False)
         assert not pofile.units[0].isfuzzy()
         assert str(pofile) == expectednonfuzzy
+        pofile.units[0].markfuzzy()
+        print str(pofile)
+        assert str(pofile) == expectedfuzzyagain or str(pofile) == posource
 
     def xtest_makeobsolete_untranslated(self):
         """Tests making an untranslated unit obsolete"""
@@ -334,6 +342,8 @@ msgstr "POT-Creation-Date: 2006-03-08 17:30+0200\n"
         posource = 'msgid "thing\nmsgstr "ding"\nmsgid "Second thing"\nmsgstr "Tweede ding"\n'
         pofile = self.poparse(posource)
         assert len(pofile.units) == 2
+        print `pofile.units[0].source`
+        assert pofile.units[0].source == u"thing"
 
     def test_malformed_obsolete_units(self):
         """Test that we handle malformed obsolete units reasonably."""
@@ -389,6 +399,7 @@ msgstr "een"
         assert unit.isobsolete()
 
         print str(pofile)
+        # Doesn't work with CPO if obsolete units are mixed with non-obsolete units
         assert str(pofile) == posource
         unit.resurrect()
         assert unit.hasplural()
@@ -396,8 +407,7 @@ msgstr "een"
 
     def test_header_escapes(self):
         pofile = self.StoreClass()
-        header = pofile.makeheader(**{"Report-Msgid-Bugs-To": r"http://qa.openoffice.org/issues/enter_bug.cgi?subcomponent=ui&comment=&short_desc=Localization%20issue%20in%20file%3A%20dbaccess\source\core\resource.oo&component=l10n&form_name=enter_issue"})
-        pofile.addunit(header)
+        pofile.updateheader(add=True, **{"Report-Msgid-Bugs-To": r"http://qa.openoffice.org/issues/enter_bug.cgi?subcomponent=ui&comment=&short_desc=Localization%20issue%20in%20file%3A%20dbaccess\source\core\resource.oo&component=l10n&form_name=enter_issue"})
         filecontents = str(pofile)
         print filecontents
         # We need to make sure that the \r didn't get misrepresented as a 
@@ -439,7 +449,7 @@ msgstr[1] "Koeie"
         print pofile
         assert str(unit) == poexpected
 
-        
+
     def test_makeobsolete_msgctxt(self):
         """Tests making a unit with msgctxt obsolete"""
         posource = '#: test.c\nmsgctxt "Context"\nmsgid "test"\nmsgstr "rest"\n'
@@ -565,11 +575,11 @@ msgstr "omskakel"
         unit = pofile.units[1]
         assert unit.getcontext() == 'Verb. Converting from "something" to "something else".'
         assert unit.getnotes() == 'Test quotes'
-        
+
         unit = pofile.units[2]
         assert unit.getcontext() == 'Verb.\nConverting from "something" to "something else".'
         assert unit.getnotes() == 'Test quotes, newlines and multiline.'
- 
+
     def test_kde_context(self):
         """Tests that kde-style msgid comments can be retrieved via getcontext()."""
         posource = '''# Test comment
@@ -605,7 +615,7 @@ msgstr "Broken _: here"
         unit = pofile.units[0]
         assert unit.source == "Broken _: here"
         assert unit.target == "Broken _: here"
-  
+
     def test_id(self):
         """checks that ids work correctly"""
         posource = r'''
@@ -638,9 +648,9 @@ msgstr[0] ""
         assert pofile.units[1].getid() == "plant"
         assert pofile.units[2].getid() == "_: Noun\nconvert"
         assert pofile.units[3].getid() == "verb\04convert"
-        # Gettext does not consider the plural to determine duplicates, only 
+        # Gettext does not consider the plural to determine duplicates, only
         # the msgid. For generation of .mo files, we might want to use this
-        # code to generate the entry for the hash table, but for now, it is 
+        # code to generate the entry for the hash table, but for now, it is
         # commented out for conformance to gettext.
 #        assert pofile.units[4].getid() == "tree\0trees"
 
@@ -658,7 +668,7 @@ msgstr ""
 
 msgid "a"
 msgstr "b"
-'''        
+'''
         pofile = self.poparse(posource)
         for line in pofile.units[0].getnotes():
             assert isinstance(line, unicode)
@@ -676,6 +686,27 @@ msgstr "プロジェクトが見つかりませんでした"
 '''
         pofile1 = self.poparse(posource)
         print pofile1.units[1].source
+        assert pofile1.units[1].source == u"I cannot locate the project\\"
         pofile2 = self.poparse(str(pofile1))
         print str(pofile2)
         assert str(pofile1) == str(pofile2)
+
+    def test_unfinished_lines(self):
+        """Test that we reasonably handle lines with a single quote."""
+        posource = r'''
+msgid ""
+msgstr ""
+"Content-Type: text/plain; charset=utf-8\n"
+
+msgid "I cannot locate the project\\"
+msgstr "start thing dingis fish"
+"
+"
+'''
+        pofile1 = self.poparse(posource)
+        print `pofile1.units[1].target`
+        assert pofile1.units[1].target == u"start thing dingis fish"
+        pofile2 = self.poparse(str(pofile1))
+        assert pofile2.units[1].target == u"start thing dingis fish"
+        print str(pofile2)
+        assert str(pofile1) == str(pofile2)
