@@ -1,12 +1,15 @@
 #!/usr/bin/env python
 
-from translate.storage import xliff
+from lxml import etree
+
+from translate.storage import xliff, lisa
 from translate.storage import test_base
-from translate.storage.placeables import X, G
+from translate.storage.placeables import StringElem
+from translate.storage.placeables.xliff import X, G
 
 class TestXLIFFUnit(test_base.TestTranslationUnit):
     UnitClass = xliff.xliffunit
-   
+
     def test_isfuzzy(self):
         """The default behaviour for XLIFF is different, so we adapt the test
         from test_base.py"""
@@ -50,6 +53,7 @@ class TestXLIFFUnit(test_base.TestTranslationUnit):
         unit.adderror(errorname='test1', errortext='New error 1.')
         assert unit.geterrors()['test1'] == 'New error 1.'
 
+
 class TestXLIFFfile(test_base.TestTranslationStore):
     StoreClass = xliff.xlifffile
     skeleton = '''<?xml version="1.0" encoding="utf-8"?>
@@ -78,72 +82,77 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         xliffunit = xlifffile.addsourceunit(u'')
 
         # Test 1
-        xliffunit.rich_source = [['foo', X('bar'), 'baz']]
+        xliffunit.rich_source = [StringElem([u'foo', X(id='bar'), u'baz'])]
         source_dom_node = xliffunit.getlanguageNode(None, 0)
         x_placeable = source_dom_node[0]
 
         assert source_dom_node.text == 'foo'
-        
+
         assert x_placeable.tag == u'x'
         assert x_placeable.attrib['id'] == 'bar'
         assert x_placeable.tail == 'baz'
-        
-        assert xliffunit.rich_source == [['foo', X('bar'), 'baz']]
+
+        xliffunit.rich_source[0].print_tree(2)
+        print xliffunit.rich_source
+        assert xliffunit.rich_source == [StringElem([StringElem(u'foo'), X(id='bar'), StringElem(u'baz')])]
 
         # Test 2
-        xliffunit.rich_source = [['foo', 'baz', G('oof', [G('zab', ['bar', 'rab'])])]]
+        xliffunit.rich_source = [StringElem([u'foo', u'baz', G(id='oof', sub=[G(id='zab', sub=[u'bar', u'rab'])])])]
         source_dom_node = xliffunit.getlanguageNode(None, 0)
         g_placeable = source_dom_node[0]
         nested_g_placeable = g_placeable[0]
 
         assert source_dom_node.text == u'foobaz'
-        
+
         assert g_placeable.tag == u'g'
-        assert g_placeable.text == u''
+        assert g_placeable.text is None
         assert g_placeable.attrib[u'id'] == u'oof'
-        assert g_placeable.tail == u''
-        
+        assert g_placeable.tail is None
+
         assert nested_g_placeable.tag == u'g'
         assert nested_g_placeable.text == u'barrab'
         assert nested_g_placeable.attrib[u'id'] == u'zab'
-        assert nested_g_placeable.tail == u''
-        
+        assert nested_g_placeable.tail is None
+
         rich_source = xliffunit.rich_source
-        assert rich_source == [['foobaz', G('oof', [G('zab', ['barrab'])])]]
+        rich_source[0].print_tree(2)
+        assert rich_source == [StringElem([u'foobaz', G(id='oof', sub=[G(id='zab', sub=[u'barrab'])])])]
 
     def test_rich_target(self):
         xlifffile = xliff.xlifffile()
         xliffunit = xlifffile.addsourceunit(u'')
 
         # Test 1
-        xliffunit.set_rich_target([['foo', X('bar'), 'baz']], 'fr')
+        xliffunit.set_rich_target([StringElem([u'foo', X(id='bar'), u'baz'])], u'fr')
         target_dom_node = xliffunit.getlanguageNode(None, 1)
         x_placeable = target_dom_node[0]
-        
+
         assert target_dom_node.text == 'foo'
         assert x_placeable.tag == u'x'
         assert x_placeable.attrib['id'] == 'bar'
         assert x_placeable.tail == 'baz'
 
         # Test 2
-        xliffunit.set_rich_target([['foo', 'baz', G('oof', [G('zab', ['bar', 'rab'])])]], 'fr')
+        xliffunit.set_rich_target([StringElem([u'foo', u'baz', G(id='oof', sub=[G(id='zab', sub=[u'bar', u'rab'])])])], u'fr')
         target_dom_node = xliffunit.getlanguageNode(None, 1)
         g_placeable = target_dom_node[0]
         nested_g_placeable = g_placeable[0]
 
         assert target_dom_node.text == u'foobaz'
-        
+
         assert g_placeable.tag == u'g'
-        assert g_placeable.text == u''
+        print 'g_placeable.text: %s (%s)' % (g_placeable.text, type(g_placeable.text))
+        assert g_placeable.text is None
         assert g_placeable.attrib[u'id'] == u'oof'
-        assert g_placeable.tail == u''
-        
+        assert g_placeable.tail is None
+
         assert nested_g_placeable.tag == u'g'
         assert nested_g_placeable.text == u'barrab'
         assert nested_g_placeable.attrib[u'id'] == u'zab'
-        assert nested_g_placeable.tail == u''
-        
-        assert xliffunit.rich_target == [['foobaz', G('oof', [G('zab', ['barrab'])])]]
+        assert nested_g_placeable.tail is None
+
+        xliffunit.rich_target[0].print_tree(2)
+        assert xliffunit.rich_target == [StringElem([u'foobaz', G(id='oof', sub=[G(id='zab', sub=[u'barrab'])])])]
 
     def test_source(self):
         xlifffile = xliff.xlifffile()
@@ -153,7 +162,7 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         print str(xlifffile)
         assert newfile.findunit("Concept") is None
         assert newfile.findunit("Term") is not None
-    
+
     def test_target(self):
         xlifffile = xliff.xlifffile()
         xliffunit = xlifffile.addsourceunit("Concept")
@@ -166,19 +175,26 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         xlifffile = xliff.xlifffile(sourcelanguage="xh")
         xmltext = str(xlifffile)
         print xmltext
-        assert xmltext.find('source-language="xh"')> 0  
+        assert xmltext.find('source-language="xh"')> 0
         #TODO: test that it also works for new files.
 
     def test_targetlanguage(self):
         xlifffile = xliff.xlifffile(sourcelanguage="zu", targetlanguage="af")
         xmltext = str(xlifffile)
         print xmltext
-        assert xmltext.find('source-language="zu"')> 0  
-        assert xmltext.find('target-language="af"')> 0  
-            
+        assert xmltext.find('source-language="zu"')> 0
+        assert xmltext.find('target-language="af"')> 0
+
     def test_notes(self):
         xlifffile = xliff.xlifffile()
         unit = xlifffile.addsourceunit("Concept")
+        # We don't want to add unnecessary notes
+        assert not "note" in str(xlifffile)
+        unit.addnote(None)
+        assert not "note" in str(xlifffile)
+        unit.addnote("")
+        assert not "note" in str(xlifffile)
+
         unit.addnote("Please buy bread")
         assert unit.getnotes() == "Please buy bread"
         notenodes = unit.xmlelement.findall(".//%s" % unit.namespaced("note"))
@@ -217,6 +233,8 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert alternatives[0].target == "ginmi"
         assert alternatives[1].target == "shikenki"
 
+        assert not unit.target
+
         unit.addalttrans("Tasting", origin="bob", lang="eng")
         alternatives = unit.getalttrans()
         assert alternatives[2].target == "Tasting"
@@ -231,6 +249,23 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert alternatives[0].target == "ginmi"
         assert alternatives[1].target == "shikenki"
 
+        #clean up:
+        alternatives = unit.getalttrans()
+        for alt in alternatives:
+            unit.delalttrans(alt)
+        unit.addalttrans("targetx", sourcetxt="sourcex")
+        # test that the source node is before the target node:
+        alt = unit.getalttrans()[0]
+        altformat = etree.tostring(alt.xmlelement)
+        print altformat
+        assert altformat.find("<source") < altformat.find("<target")
+
+        # test that a new target is still before alt-trans (bug 1098)
+        unit.target = u"newester target"
+        unitformat = str(unit)
+        print unitformat
+        assert unitformat.find("<source") < unitformat.find("<target") < unitformat.find("<alt-trans")
+
     def test_fuzzy(self):
         xlifffile = xliff.xlifffile()
         unit = xlifffile.addsourceunit("Concept")
@@ -255,6 +290,59 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert 'approved="no"' in str(unit)
         #assert unit.isfuzzy()
 
+    def test_xml_space(self):
+        """Test for the correct handling of xml:space attributes."""
+        xlfsource = self.skeleton \
+          % '''<trans-unit id="1" xml:space="preserve">
+                   <source> File  1 </source>
+               </trans-unit>'''
+        xlifffile = xliff.xlifffile.parsestring(xlfsource)
+        assert xlifffile.units[0].source == " File  1 "
+        root_node = xlifffile.document.getroot()
+        lisa.setXMLspace(root_node, "preserve")
+        assert xlifffile.units[0].source == " File  1 "
+        lisa.setXMLspace(root_node, "default")
+        assert xlifffile.units[0].source == " File  1 "
+
+        xlfsource = self.skeleton \
+          % '''<trans-unit id="1" xml:space="default">
+                   <source> File  1 </source>
+               </trans-unit>'''
+        xlifffile = xliff.xlifffile.parsestring(xlfsource)
+        assert xlifffile.units[0].source == "File 1"
+        root_node = xlifffile.document.getroot()
+        lisa.setXMLspace(root_node, "preserve")
+        assert xlifffile.units[0].source == "File 1"
+        lisa.setXMLspace(root_node, "default")
+        assert xlifffile.units[0].source == "File 1"
+
+        xlfsource = self.skeleton \
+          % '''<trans-unit id="1">
+                   <source> File  1 </source>
+               </trans-unit>'''
+        # we currently always normalize as default behaviour for xliff
+        xlifffile = xliff.xlifffile.parsestring(xlfsource)
+        assert xlifffile.units[0].source == "File 1"
+        root_node = xlifffile.document.getroot()
+        lisa.setXMLspace(root_node, "preserve")
+        assert xlifffile.units[0].source == "File 1"
+        lisa.setXMLspace(root_node, "default")
+        assert xlifffile.units[0].source == "File 1"
+
+        xlfsource = self.skeleton \
+          % '''<trans-unit id="1">
+                   <source> File  1
+</source>
+               </trans-unit>'''
+        # we currently always normalize as default behaviour for xliff
+        xlifffile = xliff.xlifffile.parsestring(xlfsource)
+        assert xlifffile.units[0].source == "File 1"
+        root_node = xlifffile.document.getroot()
+        lisa.setXMLspace(root_node, "preserve")
+        assert xlifffile.units[0].source == "File 1"
+        lisa.setXMLspace(root_node, "default")
+        assert xlifffile.units[0].source == "File 1"
+
     def test_parsing(self):
         xlfsource = self.skeleton \
           % '''<trans-unit id="1" xml:space="preserve">
@@ -279,5 +367,3 @@ class TestXLIFFfile(test_base.TestTranslationStore):
                </trans-unit>'''
         xlifffile = xliff.xlifffile.parsestring(xlfsource)
         assert xlifffile.units[0].istranslatable()
-
-
