@@ -20,14 +20,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-"""module for parsing Qt .ts files for translation
+"""Module for parsing Qt .ts files for translation.
 
+Currently this module supports the old format of .ts files. Some applictaions
+use the newer .ts format which are documented here:
 U{TS file format 4.3<http://doc.trolltech.com/4.3/linguist-ts-file-format.html>}, 
 U{Example<http://svn.ez.no/svn/ezcomponents/trunk/Translation/docs/linguist-format.txt>}
 
 U{Specification of the valid variable entries <http://doc.trolltech.com/4.3/qstring.html#arg>}, 
 U{2 <http://doc.trolltech.com/4.3/qstring.html#arg-2>}
-
 """
 
 from translate.misc import ourdom
@@ -75,7 +76,7 @@ class QtTsParser:
         translationtext = self.document.createTextNode(translation)
         translationnode.appendChild(translationtext)
         if transtype:
-            translationnode.setAttribute("type",transtype)
+            translationnode.setAttribute("type", transtype)
         messagenode.appendChild(translationnode)
         contextnode.appendChild(messagenode)
         return True
