@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2005-2009 Zuza Software Foundation
+# Copyright 2005-2010 Zuza Software Foundation
 #
 # This file is part of the Translate Toolkit.
 #
@@ -33,6 +33,8 @@ from translate.storage.placeables.lisa import xml_to_strelem, strelem_to_xml
 
 # TODO: handle translation types
 
+ID_SEPARATOR = u"\04"
+
 class xliffunit(lisa.LISAunit):
     """A single term in the xliff file."""
 
@@ -47,9 +49,9 @@ class xliffunit(lisa.LISAunit):
 
     def __init__(self, source, empty=False, **kwargs):
         """Override the constructor to set xml:space="preserve"."""
+        super(xliffunit, self).__init__(source, empty, **kwargs)
         if empty:
             return
-        super(xliffunit, self).__init__(source, empty, **kwargs)
         lisa.setXMLspace(self.xmlelement, "preserve")
 
     def createlanguageNode(self, lang, text, purpose):
@@ -185,8 +187,11 @@ class xliffunit(lisa.LISAunit):
         """Removes the supplied alternative from the list of alt-trans tags"""
         self.xmlelement.remove(alternative.xmlelement)
 
-    def addnote(self, text, origin=None):
+    def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in a "note" tag"""
+        if position != "append":
+            self.removenotes(origin=origin)
+
         if text:
             text = text.strip()
         if not text:
@@ -319,7 +324,17 @@ class xliffunit(lisa.LISAunit):
         self.xmlelement.set("id", id)
 
     def getid(self):
-        return self.xmlelement.get("id") or ""
+        uid = ""
+        try:
+            filename = self.xmlelement.iterancestors(self.namespaced('file')).next().get('original')
+            if filename:
+                uid = filename + ID_SEPARATOR
+        except StopIteration:
+            # unit has no proper file ancestor, probably newly created
+            pass
+
+        uid += self.xmlelement.get("id") or ""
+        return uid
 
     def addlocation(self, location):
         self.setid(location)
@@ -390,7 +405,7 @@ class xliffunit(lisa.LISAunit):
         else:
             return False
 
-    def multistring_to_rich(self, mstr):
+    def multistring_to_rich(cls, mstr):
         """Override L{TranslationUnit.multistring_to_rich} which is used by the
             C{rich_source} and C{rich_target} properties."""
         strings = mstr
@@ -402,7 +417,7 @@ class xliffunit(lisa.LISAunit):
         return [xml_to_strelem(s) for s in strings]
     multistring_to_rich = classmethod(multistring_to_rich)
 
-    def rich_to_multistring(self, elem_list):
+    def rich_to_multistring(cls, elem_list):
         """Override L{TranslationUnit.rich_to_multistring} which is used by the
             C{rich_source} and C{rich_target} properties."""
         return multistring([unicode(elem) for elem in elem_list])
@@ -433,38 +448,36 @@ class xlifffile(lisa.LISAfile):
         lisa.LISAfile.__init__(self, *args, **kwargs)
         self._messagenum = 0
 
-
     def initbody(self):
         self.namespace = self.document.getroot().nsmap.get(None, None)
 
         if self._filename:
-            self.body = self.getcontextnode(self._filename)
+            filenode = self.getfilenode(self._filename, createifmissing=True)
         else:
-            self.body = self.document.getroot()
-
-        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
-        sourcelanguage = filenode.get('source-language')
-        if sourcelanguage:
-            self.setsourcelanguage(sourcelanguage)
-        targetlanguage = filenode.get('target-language')
-        if targetlanguage:
-            self.settargetlanguage(targetlanguage)
+            filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        self.body = self.getbodynode(filenode, createifmissing=True)
 
     def addheader(self):
         """Initialise the file header."""
-        filenode = self.document.getroot().iterchildren(self.namespaced("file")).next()
-        filenode.set("source-language", self.sourcelanguage)
-        if self.targetlanguage:
-            filenode.set("target-language", self.targetlanguage)
+        pass
 
     def createfilenode(self, filename, sourcelanguage=None, targetlanguage=None, datatype='plaintext'):
-        """creates a filenode with the given filename. All parameters are needed
-        for XLIFF compliance."""
-        self.removedefaultfile()
+        """creates a filenode with the given filename. All parameters
+        are needed for XLIFF compliance."""
         if sourcelanguage is None:
             sourcelanguage = self.sourcelanguage
         if targetlanguage is None:
             targetlanguage = self.targetlanguage
+
+        # find the default NoName file tag and use it instead of creating a new one
+        for filenode in self.document.getroot().iterchildren(self.namespaced("file")):
+            if filenode.get("original") == "NoName":
+                filenode.set("original", filename)
+                filenode.set("source-language", sourcelanguage)
+                if targetlanguage:
+                    filenode.set("target-language", targetlanguage)
+                return filenode
+
         filenode = etree.Element(self.namespaced("file"))
         filenode.set("original", filename)
         filenode.set("source-language", sourcelanguage)
@@ -491,14 +504,50 @@ class xlifffile(lisa.LISAfile):
             filenames = []
         return filenames
 
-    def getfilenode(self, filename):
+    def getfilenode(self, filename, createifmissing=False):
         """finds the filenode with the given name"""
         filenodes = self.document.getroot().iterchildren(self.namespaced("file"))
         for filenode in filenodes:
             if self.getfilename(filenode) == filename:
                 return filenode
+        if createifmissing:
+            filenode = self.createfilenode(filename)
+            return filenode
         return None
 
+    def getids(self, filename=None):
+        if not filename:
+            return super(xlifffile, self).getids()
+
+        self.id_index = {}
+        prefix = filename + ID_SEPARATOR
+        units = (unit for unit in self.units if unit.getid().startswith(prefix))
+        for index, unit in enumerate(units):
+            self.id_index[unit.getid()[len(prefix):]] = unit
+        return self.id_index.keys()
+
+    def setsourcelanguage(self, language):
+        if not language:
+            return
+        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode.set("source-language", language)
+
+    def getsourcelanguage(self):
+        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        return filenode.get("source-language")
+    sourcelanguage = property(getsourcelanguage, setsourcelanguage)
+
+    def settargetlanguage(self, language):
+        if not language:
+            return
+        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        filenode.set("target-language", language)
+
+    def gettargetlanguage(self):
+        filenode = self.document.getroot().iterchildren(self.namespaced('file')).next()
+        return filenode.get("target-language")
+    targetlanguage = property(gettargetlanguage, settargetlanguage)
+
     def getdatatype(self, filename=None):
         """Returns the datatype of the stored file. If no filename is given,
         the datatype of the first file is given."""
@@ -563,7 +612,9 @@ class xlifffile(lisa.LISAfile):
         return bodynode
 
     def addsourceunit(self, source, filename="NoName", createifmissing=False):
-        """adds the given trans-unit to the last used body node if the filename has changed it uses the slow method instead (will create the nodes required if asked). Returns success"""
+        """adds the given trans-unit to the last used body node if the
+        filename has changed it uses the slow method instead (will
+        create the nodes required if asked). Returns success"""
         if self._filename != filename:
             if not self.switchfile(filename, createifmissing):
                 return None
@@ -615,7 +666,7 @@ class xlifffile(lisa.LISAfile):
             if ("gettext-domain-header" in (header.getrestype() or "") \
                     or xliff.getdatatype() == "po") \
                     and cls.__name__.lower() != "poxlifffile":
-                import poxliff
+                from translate.storage import poxliff
                 xliff = poxliff.PoXliffFile.parsestring(storestring)
         return xliff
     parsestring = classmethod(parsestring)
