@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2002-2006 Zuza Software Foundation
+# Copyright 2008-2010 Zuza Software Foundation
 # 
 # This file is part of translate.
 #
@@ -22,12 +22,12 @@
 
 from lxml import etree
 
-from translate.storage import base
-from translate.misc.typecheck import accepts, Self, IsCallable, IsOneOf, Any
+from translate.storage import base, xliff
+from translate.misc.typecheck import accepts, Self, IsOneOf
 from translate.misc.typecheck.typeclasses import Number
 
 class XPathTree(object):
-    @accepts(Self(), base.TranslationUnit)
+    @accepts(Self(), IsOneOf(base.TranslationUnit, type(None)))
     def __init__(self, unit = None):
         self.unit = unit
         self.children = {}
@@ -59,12 +59,14 @@ def _split_xpath(xpath):
     
     The list is reversed so that it can be used as a stack, where the top of the stack is
     the first component.
-    """    
+    """
+    if xliff.ID_SEPARATOR in xpath:
+        xpath = xpath.split(xliff.ID_SEPARATOR)[-1]
     components = xpath.split(u'/')
     components = [_split_xpath_component(component) for component in components]
     return list(reversed(components))
 
-@accepts(etree._Element, [(unicode, Number)], base.TranslationUnit)
+@accepts(IsOneOf(etree._Element, XPathTree), [(unicode, Number)], base.TranslationUnit)
 def _add_unit_to_tree(node, xpath_components, unit):
     """Walk down the tree rooted a node, and follow nodes which correspond to the
     components of xpath_components. When reaching the end of xpath_components,
